/*********************************************************************************

Copyright(c) 2016 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*!
* @file     adf703x_test.c
*
* @brief    This is a test file for adf7030_1 Radio driver development.
*
* @details  This example demonstrates how to download and configure the adf7030_1.
*           
*/

#include <string.h>
#include <stdio.h>
#include <stddef.h>
#include "system.h"
#include "common.h"

//#define __INTERNAL_DEV__

#include <services/gpio/adi_gpio.h>
#include <services/pwr/adi_pwr.h>
#include <devices/rf/adf703x/adf7030-1__spi.h>
#include <devices/rf/adf703x/adf7030-1__state.h>
#include <devices/rf/adf703x/adf7030-1__mem.h>
#include <devices/rf/adf703x/adf7030-1__patch.h>
#include <devices/rf/adf703x/adf7030-1__cfg.h>
#include <devices/rf/adf703x/adf7030-1__timer.h>
#include <devices/rf/adf703x/adi_adf7030-1_reg.h>

//ADI debug format files...
//Customer should use "*.cfg" instead as this format is the only supported one.
#include <devices/rf/adf703x/patch/CALIBRATIONS.h>
#include <devices/rf/adf703x/patch/LCPSM.h>
#include <devices/rf/adf703x/config/Usecase_20/USER_CONFIG_20.h>

#define DBG(...) \
  do { \
    sprintf(aDebugString,__VA_ARGS__); \
    test_Display(aDebugString); \
  } while(0);   
    
/* ----------------------------  SM_DATA_FAST_EXEC_CALLBACK  ---------------------------- */
#define SM_DATA_FAST_EXEC_CALLBACK_Addr                              0x20000130UL                                                 /*!< SM_DATA FAST_EXEC_CALLBACK: Address                          */
#define pSM_DATA_FAST_EXEC_CALLBACK                                  (*(volatile uint32_t *) SM_DATA_FAST_EXEC_CALLBACK_Addr)     /*!< SM_DATA FAST_EXEC_CALLBACK: Pointer                          */
#define SM_DATA_FAST_EXEC_CALLBACK_Msk                               0xFFFFFFFFUL                                                 /*!< SM_DATA FAST_EXEC_CALLBACK: Mask                             */
#define SM_DATA_FAST_EXEC_CALLBACK_Rst                               0x00000000UL                                                 /*!< SM_DATA FAST_EXEC_CALLBACK: Reset                            */

#define SM_DATA_FAST_EXEC_CALLBACK_VAL_Size                          32                                                           /*!< SM_DATA FAST_EXEC_CALLBACK: VAL Size                         */
#define SM_DATA_FAST_EXEC_CALLBACK_VAL_Pos                           0                                                            /*!< SM_DATA FAST_EXEC_CALLBACK: VAL Position                     */
#define SM_DATA_FAST_EXEC_CALLBACK_VAL_Msk                           (0xffffffffUL << SM_DATA_FAST_EXEC_CALLBACK_VAL_Pos)         /*!< SM_DATA FAST_EXEC_CALLBACK: VAL Mask                         */
#define SM_DATA_FAST_EXEC_CALLBACK_VAL_Rst                           0x0000UL                                                     /*!< SM_DATA FAST_EXEC_CALLBACK: VAL Reset                        */
#define SM_DATA_FAST_EXEC_CALLBACK_VAL_Addr                          0x20000130UL                                                 /*!< SM_DATA FAST_EXEC_CALLBACK: VAL Address                      */


/* SPI device handle */
extern ADI_SPI_HANDLE              hSPIDevice;

/* Memory required for SPI driver */
extern uint8_t SPIMem[ADI_SPI_MEMORY_SIZE];

/* Available ADF7030-1 SPI Pointer address */
extern uint32_t ADF7030_1_SPI_PNTR[8] = {  SPI_HOST_PNTR0_Addr,
                                           0x20000000,
                                           0x40004000,
                                           0x40004100,
                                           ADI_IRQ_CTRL_BASE,
                                           0x20000000,
                                           0x20000000,
                                           0x20000000 };

/* Global Timestamp */
extern ADI_ADF7030_1_TIMESTAMP adf7030_1_time;
extern ADI_ADF7030_1_TIMESTAMP adf7030_1_time_capture;  


extern void adi_initpinmux(void);


void CHECK( uint32_t condition )
{
    if(condition)
    {
        DBG("PASS\n");
    }else
    {
        DBG("FAIL\n");
    } 
}

void DISPLAY_PATCH_INFO(char * PatchName, version_info_t * pPathInfo)
{
    DBG("%s Informations:\n", PatchName);
    DBG("   -Name:           %s\n",     pPathInfo->patch_name);
    DBG("   -build_number:   0x%04x\n", pPathInfo->build_number);
    DBG("   -family_str:     %.4s\n",   pPathInfo->family_str);
    DBG("   -adiid:          0x%04x\n", pPathInfo->adiid);
    DBG("   -chipid:         0x%04x\n", pPathInfo->chipid);
    DBG("   -full_layer_num: 0x%02x\n", pPathInfo->full_layer_num);
    DBG("   -eco_num:        0x%02x\n", pPathInfo->eco_num);
    DBG("   -svn_version:    0x%04x\n", pPathInfo->svn_version);
}

void main(void)
{
  
  SystemInit();
  
  adi_initpinmux();
  
  test_Init();
  
  do
  {
    if(ADI_PWR_SUCCESS != adi_pwr_Init())
    {
      printf("Failed to intialize the power service\n");
      break;
    }
    if(ADI_PWR_SUCCESS != adi_pwr_SetClockDivider(ADI_CLOCK_HCLK,1))
    {
      printf("Failed to intialize the power service\n");
      break;
    }
    if(ADI_PWR_SUCCESS != adi_pwr_SetClockDivider(ADI_CLOCK_PCLK,1))
    {
      printf("Failed to intialize the power service\n");
      break;
    }
    
    if(ADI_PWR_SUCCESS != adi_pwr_UpdateCoreClock())
    {
      printf("Failed to update system clks\n");
      break;
    }
    
    /* Initialize SPI service for communication with adf7030-1 */
    if(adf7030_1__SPI_Init() != SUCCESS)
    {
      printf("Failed to intialize the SPI service\n");  
      break;
    }
    
    if(adf7030_1__SPI_SetSpeed(SPI_DEV_BITRATE) != SUCCESS)
    {
      printf("Failed to change SPI speed\n");  
      break;
    }
    
    /* Initialize TIMER service for communication with adf7030-1 */
    if(adf7030_1__TIMER_Init() != SUCCESS)
    {
      printf("Failed to intialize the TIMER service\n");  
      break;
    }
    
    adi_gpio_SetLow(ADI_GPIO_PORT0, ADI_GPIO_PIN_12);
    adi_gpio_SetLow(ADI_GPIO_PORT0, ADI_GPIO_PIN_15);
    adi_gpio_SetLow(ADI_GPIO_PORT2, ADI_GPIO_PIN_0);
    adi_gpio_OutputEnable(ADI_GPIO_PORT0, ADI_GPIO_PIN_12, true);
    adi_gpio_OutputEnable(ADI_GPIO_PORT0, ADI_GPIO_PIN_15, true);
    adi_gpio_OutputEnable(ADI_GPIO_PORT2, ADI_GPIO_PIN_0, true);
    
    do{
      
      adf7030_1__TIMER_ClrTime(&adf7030_1_time);
      
      adi_gpio_SetHigh(ADI_GPIO_PORT0, ADI_GPIO_PIN_15);
      WAIT_US(100);
      adi_gpio_SetLow(ADI_GPIO_PORT0, ADI_GPIO_PIN_15);
      
      //----------------------------------------------------------------------
      
      if(adf7030_1__SPI_SetMMapPointers( hSPIDevice, &ADF7030_1_SPI_PNTR[PNTR_CUSTOM0_ADDR]) != SUCCESS)
      {
        DBG("Failed writing SPI_CUSTOM_PNTR\n");
      }
      
      if(adf7030_1__SPI_GetMMapPointers( hSPIDevice, &ADF7030_1_SPI_PNTR[PNTR_CUSTOM0_ADDR]) != SUCCESS)
      {
        DBG("Failed reading SPI_CUSTOM_PNTR\n");
      }
      for(uint8_t i = PNTR_SETUP_ADDR; i <= PNTR_CUSTOM2_ADDR; i++){
        DBG("-> ADF7030_1_SPI_PNTR[%d] = 0x%08x\n",i ,ADF7030_1_SPI_PNTR[i]);
      }
      
      //----------------------------------------------------------------------
      
      version_info_t PatchInfo__Readback;
      
      /* Testing Calibration patch*/
      DBG("\nTesting %s patch:\n", PATCH_CALIBRATIONS.Name);
      
      DBG("--> Transfering %s (%d bytes) to the PHY...", PATCH_CALIBRATIONS.Name, PATCH_CALIBRATIONS.Size);
      if(adf7030_1__WritePatch(hSPIDevice, &PATCH_CALIBRATIONS) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      DBG("--> Checking %s integrity...",PATCH_CALIBRATIONS.Name);
      if(adf7030_1__VerifyPatch(hSPIDevice, &PATCH_CALIBRATIONS) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      DBG("--> Transfert %s info data (%d bytes)...", PATCH_CALIBRATIONS.Name, sizeof(version_info_t));
      if(adf7030_1_WritePatchInfo(hSPIDevice, PATCH_CALIBRATIONS.pInfo, PATCH_CALIBRATIONS.InfoAddr) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");  
      }
      
      DBG("--> Reading %s info data (%d bytes)...", PATCH_CALIBRATIONS.Name, sizeof(version_info_t));
      if(adf7030_1_ReadPatchInfo(hSPIDevice, &PatchInfo__Readback, PATCH_CALIBRATIONS.InfoAddr) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK( (memcmp(PATCH_CALIBRATIONS.pInfo, &PatchInfo__Readback, sizeof(version_info_t) ) == 0) );
        
        DISPLAY_PATCH_INFO(PATCH_CALIBRATIONS.Name, &PatchInfo__Readback);
      }
      
      DBG("--> Enabling %s patch...", PATCH_CALIBRATIONS.Name);
      if(adf7030_1__InjectPatch(hSPIDevice, &PATCH_CALIBRATIONS) != SUCCESS){
        DBG("FAIL\n");
      }else{
        if((0x20000000 + PATCH_CALIBRATIONS.InjectSeq) == adf7030_1__READ_FIELD(SM_DATA_FAST_EXEC_CALLBACK_VAL)){
          DBG("PASS\n");
        }else{
          DBG("FAIL\n");
        }
      }
      
      DBG("--> Disabling %s patch...", PATCH_CALIBRATIONS.Name);
      if(adf7030_1__EjectPatch(hSPIDevice, &PATCH_CALIBRATIONS) != SUCCESS){
        DBG("FAIL\n");
      }else{
        if((0x20000000 + PATCH_CALIBRATIONS.EjectSeq) == adf7030_1__READ_FIELD(SM_DATA_FAST_EXEC_CALLBACK_VAL)){
          DBG("PASS\n");
        }else{
          DBG("FAIL\n");
        }
      }
      
      //----------------------------------------------------------------------
      
      DBG("\nTesting %s patch:\n", PATCH_LCPSM.Name);
      
      DBG("--> Transfering %s (%d bytes) to the PHY...", PATCH_LCPSM.Name, PATCH_LCPSM.Size);
      if(adf7030_1__WritePatch(hSPIDevice, &PATCH_LCPSM) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      DBG("--> Checking %s integrity...",PATCH_LCPSM.Name);
      if(adf7030_1__VerifyPatch(hSPIDevice, &PATCH_LCPSM) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      DBG("--> Transfert %s info data (%d bytes)...", PATCH_LCPSM.Name, sizeof(version_info_t));
      if(adf7030_1_WritePatchInfo(hSPIDevice, PATCH_LCPSM.pInfo, PATCH_LCPSM.InfoAddr) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");  
      }
      
      DBG("--> Reading %s info data (%d bytes)...", PATCH_LCPSM.Name, sizeof(version_info_t));
      if(adf7030_1_ReadPatchInfo(hSPIDevice, &PatchInfo__Readback, PATCH_LCPSM.InfoAddr) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK( (memcmp(PATCH_LCPSM.pInfo, &PatchInfo__Readback, sizeof(version_info_t) ) == 0) );
        
        DISPLAY_PATCH_INFO(PATCH_LCPSM.Name, &PatchInfo__Readback);
      }
      
      
      DBG("--> Enabling %s patch...", PATCH_LCPSM.Name);
      if(adf7030_1__InjectPatch(hSPIDevice, &PATCH_LCPSM) != SUCCESS){
        DBG("FAIL\n");
      }else{
        if((0x20000000 + PATCH_LCPSM.InjectSeq) == adf7030_1__READ_FIELD(SM_DATA_FAST_EXEC_CALLBACK_VAL)){
          DBG("PASS\n");
        }else{
          DBG("FAIL\n");
        }
      }
      
      DBG("--> Disabling %s patch...", PATCH_LCPSM.Name);
      if(adf7030_1__EjectPatch(hSPIDevice, &PATCH_LCPSM) != SUCCESS){
        DBG("FAIL\n");
      }else{
        if((0x20000000 + PATCH_LCPSM.EjectSeq) == adf7030_1__READ_FIELD(SM_DATA_FAST_EXEC_CALLBACK_VAL)){
          DBG("PASS\n");
        }else{
          DBG("FAIL\n");
        }
      }
      
      //----------------------------------------------------------------------        
      
      DBG("\nTesting %s configuration:\n", USER_CONFIG_20.Name);
      
      DBG("--> Transfering %s (%d bytes) to the PHY...", USER_CONFIG_20.Name, USER_CONFIG_20.Size);
      if(adf7030_1__WriteConfig(hSPIDevice, &USER_CONFIG_20) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      DBG("--> Checking %s integrity...", USER_CONFIG_20.Name);
      if(adf7030_1__VerifyConfig(hSPIDevice, &USER_CONFIG_20) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      //----------------------------------------------------------------------
      
      uint8_t ADI_RF_CONFIG_UC20[] = {
#include <devices/rf/adf703x/config/Usecase_20/CFG3_usecase_20.cfg>
      };
      
      DBG("\nTesting ADI Configuration format:\n");
      DBG("--> Transfering USECASE Configuration to the PHY...");
      if(adf7030_1__SendConfiguration(hSPIDevice, ADI_RF_CONFIG_UC20, sizeof(ADI_RF_CONFIG_UC20)) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      //----------------------------------------------------------------------
      
      uint8_t ADI_OfflineCalibrations[] = {
#include <devices/rf/adf703x/patch/OfflineCalibrations.cfg>
      };
      
      DBG("\nTesting ADI Configuration format:\n");
      DBG("--> Transfering PATCH to the PHY...");
      if(adf7030_1__SendConfiguration(hSPIDevice, ADI_OfflineCalibrations, sizeof(ADI_OfflineCalibrations)) != SUCCESS){
        DBG("FAIL\n");
      }else{
        DBG("PASS\n");
      }
      
      //----------------------------------------------------------------------
      
      if(adf7030_1__XferCmd(hSPIDevice, PHY_OFF ) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK((PHY_OFF == adf7030_1__READ_FIELD(MISC_FW_CURR_STATE))); 
      }
      
      if(adf7030_1__XferCmd(hSPIDevice, DO_CFG_DEV ) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK((PHY_OFF == adf7030_1__READ_FIELD(MISC_FW_CURR_STATE)));
      }
      
      if(adf7030_1__XferCmd(hSPIDevice, PHY_ON ) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK((PHY_ON == adf7030_1__READ_FIELD(MISC_FW_CURR_STATE)));
      }
      
      if(adf7030_1__XferCmd(hSPIDevice, PHY_OFF ) != SUCCESS){
        DBG("FAIL\n");
      }else{
        CHECK((PHY_OFF == adf7030_1__READ_FIELD(MISC_FW_CURR_STATE)));
      }
      
    }while(1);      
    
    /* Uninitialize TIMER service for communication with adf7030-1 */
    if(adf7030_1__TIMER_UnInit() != SUCCESS)
    {
      printf("Failed to unintialize the TIMER service\n");  
      //break;
    }
    
    /* Uninitializes SPI device */
    if(adf7030_1__SPI_UnInit() != SUCCESS)
    {
      printf("Failed to unintialize the SPI service\n");  
      //break;
    }
    
  }while(1);
  
}


