    
    
    // thumb_aligned_memset( void* dest, const uint32_t setval, uint32_t bytesToCopy )
    // Set 4-byte aligned memory range. "BytesToCopy" must be a multiple of 4.
    // @author Lee Coakley
    
    // General idea is to copy in large chunks using as few in-loop instructions as possible.
    // Large copies have the best performance because they have the least loop overhead.
    // First it tries 60-byte chunks, then 20, then 4.
    // 20 is the largest transfer possible in one instruction without clobbering registers.
    
    // Inputs:
    //   r0: dest address
    //   r1: setval initdata
    //   r2: bytes to copy
    
    public thumb_aligned_memset
    section .text: CODE(4)
        
        thumb_aligned_memset:
            push {r4-r7,LR}     // Save non-scratch registers and link register on the stack.
            
            mov r3, r1          // Load reg r3, r4, r5, r6, r7 with content of r1
            mov r4, r1
            mov r5, r1
            mov r6, r1
            mov r7, r1
            
        test60:
            cmp r2, #60         // Compare bytecount with 60
            blt test20          // If r2 < 60, jump to test20
            subs r2, #60        // Setup for compare with zero.
        loop60:                 // Main loop: copies 60-byte chunks.
            stmia r0!, {r3-r7}  // Store 20 bytes from 5 registers, r0 += 20
            stmia r0!, {r3-r7}  // "
            stmia r0!, {r3-r7}  // "
            subs r2, #60        // Subtract 60 from the remaining byte count and update the condition flags.
            bge loop60          // If (r2 - 60 >= 0) continue loop
            adds r2, #60        // Clean up for next section.
            
        test20:
            cmp r2, #20         // Compare bytecount with 20
            blt test4           // If r2 < 20, jump to test4
            subs r2, #20        // Setup for compare with zero.
        loop20:                 // Secondary loop: copies 20-byte chunks.
            stmia r0!, {r3-r7}  // "
            subs r2, #20        // -20 and set flags
            bge loop20          // If (r2 - 20 >= 0) continue loop
            adds r2, #20        // Clean up for next section.
            
        test4:
            cmp r2, #4          // Compare bytecount with 4
            blt exit            // If less, jump to exit
            subs r2, #4         // Setup for compare with zero.
        loop4:                  // Tertiary loop: copy leftover 4-byte words.
            stmia r0!, {r3}     // Store 4 bytes from r3. r0 += 4
            subs r2, #4         // -4 and set flags
            bge loop4           // If (r2 - 4) >= 0 continue loop
            
        exit:
            pop {r4-r7,PC}      // Restore dirtied registers and return (loading link register into program counter)
    
    end
    
    
    
    
    
    
    
    