#ifndef _ADF7030_1__PATCH_H_
#define _ADF7030_1__PATCH_H_

#include <drivers/spi/adi_spi.h>
#include <devices/rf/adf703x/adi_adf7030-1_reg.h>

/** \addtogroup adf7030-1 adf7030-1 Driver
 *  @{
 */

/** \addtogroup adf7030-1__patch PHY Patch Interface
 *  @{
 */

extern uint32_t ADF7030_1_SPI_PNTR[8];


//Forward Typedef declarartion
typedef struct PATCH_DESCRIPTOR_Type            PATCH_DESCRIPTOR_Type;


/** Generic Type to describes the Radio PHY Patch Information data.
*/
typedef struct {
    //char patch_name[69];
    char patch_name[73];
    uint16_t build_number;
    char family_str[4];
    uint16_t adiid;
    uint16_t chipid;
    uint8_t full_layer_num;
    uint8_t eco_num;
    uint16_t svn_version;
} version_info_t;


struct PATCH_DESCRIPTOR_Type{
    char		        Name[16];	///String with name of Patch
    uint16_t 	                Size;		///Total size of the Patch
    uint16_t                    nbBlock;        ///Number of data blocks
    version_info_t *            pInfo;          ///Pointer to the Patch info structure in the host memory
    uint32_t                    InfoAddr;       ///Start location of the Patch info structure in the PHY
    uint16_t                    InjectSeq;      ///Enable patch sequence
    uint16_t                    EjectSeq;       ///Disable patch sequence
    DATA_BLOCK_DESCRIPTOR_Type  BLOCKS[];
};
  
/* Write patch data to Radio PHY */
uint32_t adf7030_1__WritePatch(
    ADI_SPI_HANDLE hSPIDevice,                              
    PATCH_DESCRIPTOR_Type * pPATCH                                
);

/* Read patch data from Radio PHY */
uint32_t adf7030_1__ReadPatch(
    ADI_SPI_HANDLE hSPIDevice,                              
    PATCH_DESCRIPTOR_Type * pPATCH                                
);

/* Enable Patch sequence */
uint32_t adf7030_1__InjectPatch(
    ADI_SPI_HANDLE hSPIDevice,                              
    PATCH_DESCRIPTOR_Type * pPATCH                                
);

/* Disable Patch sequence */
uint32_t adf7030_1__EjectPatch(
    ADI_SPI_HANDLE hSPIDevice,                              
    PATCH_DESCRIPTOR_Type * pPATCH                                
);

/* Verify patch integrity */
uint32_t adf7030_1__VerifyPatch(
    ADI_SPI_HANDLE hSPIDevice,                              
    PATCH_DESCRIPTOR_Type * pPATCH                                
);
    
/* Write patch description to PHY*/
uint32_t adf7030_1_WritePatchInfo(
    ADI_SPI_HANDLE hSPIDevice,                              
    version_info_t * pPathInfo,
    uint32_t PhyAddr
); 

/* Read patch description from PHY*/
uint32_t adf7030_1_ReadPatchInfo(
    ADI_SPI_HANDLE hSPIDevice,                              
    version_info_t * pPathInfo,
    uint32_t PhyAddr
);                              

/* Transfers memory blocks between Host shadow and the radio PHY */
uint32_t adf7030_1__XferPatch(
    ADI_SPI_HANDLE hSPIDevice,
    PATCH_DESCRIPTOR_Type * pPATCH,
    bool READ_nWRITE,
    bool CHECK_ONLY
);



/** @} */ /* End of group adf7030-1__patch PHY Patch Interface */
/** @} */ /* End of group adf7030-1 adf7030-1 Driver */

#endif /* _ADF7030_1__PATCH_H_ */