#ifndef _ADF7030_1__STATE_H_
#define _ADF7030_1__STATE_H_

#include <drivers/spi/adi_spi.h>
#include <devices/rf/adf703x/adi_adf7030-1_reg.h>

/** \addtogroup adf7030-1 adf7030-1 Driver
 *  @{
 */

/** \addtogroup adf7030-1__state PHY State Machine Interface
 *  @{
 */

/*! Enumeration of different radio firmware states */
typedef enum {
    PHY_SLEEP                   = 0x00,
    PHY_OFF                     = 0x01,
    PHY_ON                      = 0x02,
    PHY_RX                      = 0x03,
    PHY_TX                      = 0x04,
    DO_CFG_DEV                  = 0x05,
    PHY_CCA                     = 0x06,
    PHY_PATCH                   = 0x07,
    DO_IRCAL                    = 0x08,
    DO_CAL                      = 0x09,
    DO_TEMP_MEAS                = 0x0A,
    DO_XTAL_TCAL                = 0x0B,
    DO_LFRC_CAL                 = 0x0C,

/*! \cond PRIVATE */    
//Debug states
    DO_ROMCRC_CONTINUOUS        = 0x0D,
    DO_RAMCRC_CONTINUOUS        = 0x0E,
    DO_MCRCRC_CONTINUOUS        = 0x0F,
    DO_NOP_FOREVER              = 0x10,
    DO_SNOOP_TESTMODES_LOOPBACK = 0x11,
    D0_ROMCRC_SOFT_CONTINUOUS   = 0x12,
    D0_RAMCRC_SOFT_CONTINUOUS   = 0x13,
    D0_MCRCRC_SOFT_CONTINUOUS   = 0x14,
    D0_CAPTURE_RX_CONTINUOUS    = 0x15,
    DO_ANC_PLL_CAL              = 0x16,
    DO_ADC_NOTCH_CAL            = 0x17,
    DO_OCL_CAL                  = 0x18,
    DO_FILT_CAL                 = 0x19,
    DO_VCO_KV_CAL               = 0x1A,
    DO_HFRC_OFF                 = 0x1D,
    DO_ANC_PLL_ON               = 0x1E,
    DO_PHY_ERROR_HANDLER        = 0x1F
/*! \endcond */
} ADI_ADF7030_1_RADIO_STATE;

/*! Enumeration of different radio command type */
typedef enum {
    RADIO_CMD                   = (0x1 << 7),
    SPECIAL_CMD                 = (0x1 << 6),
} ADI_ADF7030_1_RADIO_CMD_TYPE;


#define TRANSITION_STATUS_TRANSITION    0
#define TRANSITION_STATUS_EXECUTING     1
#define TRANSITION_STATUS_IDLE          2


/*! \cond PRIVATE */ 
/* state machine radio commands */
#define CMD_PHY_SLEEP           RADIO_COMMAND | FW_STATE_PHY_SLEEP      //Performs a transition of the device into the PHY_SLEEP state
#define CMD_PHY_OFF             RADIO_COMMAND | FW_STATE_PHY_OFF        //Performs a transition of the device into the PHY_OFF state
#define CMD_PHY_ON              RADIO_COMMAND | FW_STATE_PHY_ON         //Performs a transition of the device into the PHY_ON state
#define CMD_PHY_RX              RADIO_COMMAND | FW_STATE_PHY_RX         //Performs a transition of the device into the PHY_RX state
#define CMD_PHY_TX              RADIO_COMMAND | FW_STATE_PHY_TX         //Performs a transition of the device into the PHY_TX state
#define CMD_CONFIG_DEV          RADIO_COMMAND | FW_STATE_CONFIG_DEV     //Configures the ADF703x based on the Radio Profile
#define CMD_GET_RSSI            RADIO_COMMAND | FW_STATE_GET_RSSI       //Performs an RSSI measurement
#define CMD_PHY_PATCH           RADIO_COMMAND | FW_STATE_PHY_PATCH  //Prepares the program RAM for a firmware module download
#define CMD_DO_CAL              RADIO_COMMAND | FW_STATE_DO_CAL         //Executes selected calibration routines
#define CMD_NOP                 0xFF
#define CMD_RESET               0xC7

/* special radio commands */
#define CMD_RAM_LOAD_DONE       RADIO_COMMAND | SPCNTRN  | 0x08 //Configures the ADF703x to use a downloaded patch by restarting the ADF703x
#define CMD_IRQ1_DIS_IRQ0_DIS   RADIO_COMMAND | SPCNTRN  | 0x0C //Disable IRQ_IN0 and IRQ_IN1 in triggering preloaded radio commands
#define CMD_IRQ1_DIS_IRQ0_EN    RADIO_COMMAND | SPCNTRN  | 0x0D //Disable IRQ_IN1 and enable IRQ_IN0 in triggering preloaded radio commands
#define CMD_IRQ1_EN_IRQ0_DIS    RADIO_COMMAND | SPCNTRN  | 0x0E //Enable IRQ_IN1 and disable IRQ_IN0 in triggering preloaded radio commands
#define CMD_IRQ1_EN_IRQ0_EN     RADIO_COMMAND | SPCNTRN  | 0x0F //Enable IRQ_IN1 and IRQ_IN0 in triggering preloaded radio commands

/*status */
#define STATUS_SPI_READY(x)             (x & (0x1 << 7))
#define STATUS_IRQ_STATUS(x)            (x & (0x1 << 6))
#define STATUS_CMD_READY(x)             (x & (0x1 << 5))
#define STATUS_ERR(x)                   (x & (0x1 << 3))
#define STATUS_TRANSITION_STATUS(x)     ((x & 0x6) >> 1)



/*! \endcond */

/* Transfers Radio PHY Command */
uint32_t adf7030_1__XferCmd(
    ADI_SPI_HANDLE hSPIDevice,
    ADI_ADF7030_1_RADIO_STATE PHY_CMD
);



/** @} */ /* End of group adf7030-1__state PHY State Machine Interface */
/** @} */ /* End of group adf7030-1 adf7030-1 Driver */

#endif /* _ADF7030_1__PATCH_H_ */