#ifndef _ADF7030_1__TIMER_H_
#define _ADF7030_1__TIMER_H_

/** \addtogroup adf7030-1 adf7030-1 Driver
 *  @{
 */

/** \addtogroup adf7030-1__timer Timers Interface layer
 *  @{
 */


#include <services/tmr/adi_tmr.h>
#include <devices/rf/adf703x/adi_adf7030-1_reg.h>


/* Quick fix to compensate for a pclk divided by 4 somewhere */
//Somehow the output of timer is 4x the expected value indicating pclk might be divided by 4
#define ERROR_COMPENSATION_DIV 4

/* Define delay for starting timer */ 
#define ERROR_TON 12

/* Define delay for Callback routine */ 
#define ERROR_CB 12

/* Define delay for stopping timer */
#define ERROR_TOFF 12

/* Define global min uS load value */
#define TOTAL_TMR_ERROR (ERROR_TON + ERROR_CB + ERROR_TOFF)

typedef struct{
    uint16_t ticks;
    uint16_t ms;
}ADI_ADF7030_1_TIMESTAMP;

#define WAIT_US(us) { \
                      adf7030_1__TIMER_Wait_uS(us, GPTimer0Callback); \
                    };
     
uint32_t adf7030_1__TIMER_Init
(
    void
);

uint32_t adf7030_1__TIMER_UnInit
(
    void
);

uint32_t adf7030_1__TIMER_ClrTime
(
    ADI_ADF7030_1_TIMESTAMP * pTime
);

uint32_t adf7030_1__TIMER_GetTime
(
    ADI_ADF7030_1_TIMESTAMP * pTime
);

uint32_t adf7030_1__TIMER_Start_uS
(
    const uint16_t u_sec,
    ADI_CALLBACK const pfCallback
);

uint32_t adf7030_1__TIMER_Stop_uS
(
    void
);

uint32_t adf7030_1__TIMER_Wait_uS
(
    const uint16_t u_sec,
    ADI_CALLBACK const pfCallback
);

void GPTimer0Callback
(
    void *pCBParam,
    uint32_t Event,
    void *pArg
);

void GPTimer2Callback
(
    void *pCBParam,
    uint32_t Event,
    void *pArg
);

uint32_t adf7030_1__TIMER_Active_Delay_uS
(
    const uint16_t delay_us
);

/** @} */ /* End of group adf7030-1__timer Timers Interface layer */
/** @} */ /* End of group adf7030-1 adf7030-1 Driver */

#endif /* _ADF7030_1__TIMER_H_ */