
/*!
 *****************************************************************************
 * @file    CALIBRATIONS.h
 * @brief   Firmware header file containing binaries of CALIBRATIONS patch
 * @version $REVISION: $
 * @date    $DATE: $
 *----------------------------------------------------------------------------
 *
Copyright (c) 2010-2016 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:
- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer.
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.
- Modified versions of the software must be conspicuously marked as such.
- This software is licensed solely and exclusively for use with processors
  manufactured by or for Analog Devices, Inc.
- This software may not be combined or merged with other code in any manner
  that would cause the software to become subject to terms and conditions
  which differ from those listed here.
- Neither the name of Analog Devices, Inc. nor the names of its
  contributors may be used to endorse or promote products derived
  from this software without specific prior written permission.
- The use of this software may or may not infringe the patent rights of one
  or more patent holders.  This license does not release you from the
  requirement that you obtain separate licenses from these patent holders
  to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON- 
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

*****************************************************************************/ 

/**
 * @brief		The ADF7030-1 RX calibrations are implemented in FW. The ADC NOTCH and OCL offline calibrations
 * 				are included in the P3.2 ROM memory while the remaining ones are part of a single patch called “OffLineCals”.
 * 				A calibration can be executed both in response to a DO_CAL command (0x89) from the PHY_ON state only or,
 * 				alternatively, in response to the individual calibration commands.
 * 
 * @details		This file is for ADI Internal development only. 
 * 
 * HOST SEQUENCES:
 * --------------- 
 * 	
 * 	- Enabling the Calibration patch for the first time:
 * 		0. Radio PHY must be in PHY_OFF
 *  	1. Load the profiles, Generic Pkt, LUT's,
 *  	2. Load Freq Changes, Calibration Enable Bits etc.
 *  	3. Issue Cmd_Config_Dev.
 *  	4. Transfert the Calibration F/W
 *  	5. Enable CALIBRATIONS patch
 *  	6. Issue Phy On
 *  	7. Issue Do Cal
 *  	8. Readback and save calibration results
 * 		9. Disable CALIBRATIONS patch
 * 		
 * 	- Disabling CALIBRATIONS patch
 * 		1. Write (0x20000000 + <EjectSeq>) at location 0x20000130
 * 		
 * 	- Enabling CALIBRATIONS patch
 * 		1. Write (0x20000000 + <InjectSeq>) at location 0x20000130
 *  
 * 	@note ___The CALIBRATIONS f/w reside outside the BBRAM, user must reload the patch between sleep episodes___
 * 	@note ___Calibration results should save off cal results in the event of a system reset or power cycle___
 * 
 *
 * HOWTO: (ADI Radio drivers)
 * ------
 * 	
 * 	- Download patch to PHY Radio:
 * 		
 * 		adf7030_1__WritePatch(hSPIDevice, &PATCH_CALIBRATIONS);
 *  
 * 	- Enable the patch:
 * 	     
 * 		adf7030_1__InjectPatch(hSPIDevice, &PATCH_CALIBRATIONS);
 *  	
 * 	- Disable the patch:
 * 	
 * 		adf7030_1__EjectPatch(hSPIDevice, &PATCH_CALIBRATIONS);
 *  	
 * 	- Verify patch integrity on the PHY:
 * 	
 * 		adf7030_1__VerifyPatch(hSPIDevice, &PATCH_CALIBRATIONS);
 *
 */ 


#ifndef __PATCH_CALIBRATIONS_HEADER__
#define __PATCH_CALIBRATIONS_HEADER__

static const uint8_t ADF7030_1__PATCH_CALIBRATIONS_BLOCK_0[] = { // 0x2000112c - 6512
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xe3, 0x1a, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xb7, 0x29, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xa9, 0x19, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x5d, 0x2a, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x6d, 0x1b, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x29, 0x2a, 0x00, 0x00,
0xf1, 0xb5, 0x84, 0xb0, 0x80, 0x79, 0x20, 0x21, 0x01, 0x43, 0x04, 0x98, 0x81, 0x71, 0x04, 0x98,
0x80, 0x68, 0x78, 0x49, 0x04, 0x9a, 0x11, 0x61, 0x00, 0x6f, 0x81, 0x01, 0x89, 0x0c, 0x03, 0x91,
0xc0, 0x06, 0xc0, 0x0e, 0x02, 0x90, 0x74, 0x4f, 0x38, 0x00, 0x34, 0x30, 0x00, 0x90, 0x3b, 0x00,
0x14, 0x33, 0x3a, 0x00, 0x01, 0xa9, 0x04, 0x98, 0x00, 0xf0, 0x52, 0xfa, 0x05, 0x00, 0x03, 0xd1,
0x04, 0x98, 0x00, 0xf0, 0x59, 0xf8, 0x05, 0x00, 0x00, 0x2d, 0x4e, 0xd1, 0x00, 0x24, 0x47, 0xe0,
0xd8, 0x48, 0x00, 0x68, 0x69, 0x49, 0x01, 0x40, 0x38, 0x78, 0x40, 0x04, 0x08, 0x43, 0xd5, 0x49,
0x08, 0x60, 0x48, 0x68, 0xd4, 0x49, 0x01, 0x40, 0x80, 0x20, 0x00, 0x02, 0x08, 0x43, 0xd1, 0x49,
0x48, 0x60, 0xd2, 0x48, 0xc0, 0x68, 0x80, 0x0b, 0x80, 0x03, 0x03, 0x99, 0x01, 0x43, 0xcf, 0x48,
0xc1, 0x60, 0xa0, 0x00, 0x3e, 0x18, 0xcd, 0x48, 0x40, 0x68, 0x00, 0x0d, 0x00, 0x05, 0x71, 0x6b,
0x01, 0x43, 0xca, 0x48, 0x41, 0x60, 0x02, 0x98, 0x41, 0x02, 0x80, 0x00, 0x08, 0x43, 0xc5, 0x49,
0x09, 0x68, 0xc7, 0x4a, 0x0a, 0x40, 0x02, 0x43, 0xc2, 0x48, 0x02, 0x60, 0x05, 0x21, 0x03, 0x20,
0xff, 0xf7, 0x76, 0xff, 0xc1, 0x48, 0x00, 0x68, 0x9f, 0x49, 0x01, 0x40, 0x9f, 0x48, 0x08, 0x43,
0xbe, 0x49, 0x08, 0x60, 0x00, 0x2d, 0x02, 0xd1, 0x00, 0xf0, 0xde, 0xf9, 0x05, 0x00, 0x00, 0x2d,
0x05, 0xd1, 0x72, 0x69, 0x21, 0x00, 0x04, 0x98, 0x00, 0xf0, 0x92, 0xf8, 0x05, 0x00, 0x64, 0x1c,
0x68, 0x46, 0x00, 0x79, 0xe4, 0xb2, 0x84, 0x42, 0xb2, 0xd3, 0x00, 0x2d, 0x02, 0xd0, 0xa8, 0x00,
0x04, 0x99, 0xc8, 0x71, 0x05, 0xb0, 0xf0, 0xbd, 0x70, 0xb5, 0x81, 0x68, 0x70, 0x22, 0x8a, 0x5c,
0xd3, 0x06, 0xdb, 0x0e, 0x3b, 0x4a, 0x02, 0x61, 0xac, 0x4a, 0xd4, 0x6d, 0x01, 0x25, 0x25, 0x43,
0xd5, 0x65, 0x14, 0x68, 0xab, 0x4d, 0x25, 0x40, 0x94, 0x0d, 0x2c, 0x43, 0x14, 0x60, 0xaa, 0x4c,
0xa5, 0x68, 0xaa, 0x4e, 0x2e, 0x40, 0x9d, 0x00, 0x35, 0x43, 0x5b, 0x02, 0x2b, 0x43, 0xbc, 0x4d,
0x1d, 0x43, 0xa5, 0x60, 0x23, 0x68, 0xbb, 0x4d, 0x1d, 0x40, 0xbb, 0x4b, 0x2b, 0x43, 0x23, 0x60,
0x63, 0x68, 0xc0, 0x25, 0xed, 0x02, 0x1d, 0x43, 0x65, 0x60, 0x4b, 0x68, 0x9b, 0x01, 0x9b, 0x09,
0xb6, 0x4d, 0xab, 0x42, 0x63, 0x69, 0x06, 0xda, 0xb5, 0x4d, 0x1d, 0x40, 0x80, 0x23, 0xdb, 0x02,
0x2b, 0x43, 0x63, 0x61, 0x03, 0xe0, 0xc0, 0x25, 0x2d, 0x03, 0x1d, 0x43, 0x65, 0x61, 0x63, 0x69,
0x80, 0x25, 0x6d, 0x03, 0x1d, 0x43, 0x65, 0x61, 0x63, 0x69, 0x1c, 0x25, 0xab, 0x43, 0x04, 0x25,
0x1d, 0x43, 0x65, 0x61, 0xa3, 0x68, 0x80, 0x25, 0xed, 0x03, 0x1d, 0x43, 0xa5, 0x60, 0xe3, 0x68,
0x95, 0x0b, 0x1d, 0x43, 0xe5, 0x60, 0x95, 0x68, 0xb9, 0x4b, 0x2b, 0x40, 0xcd, 0x6e, 0xad, 0x0e,
0x2d, 0x03, 0x1d, 0x43, 0x95, 0x60, 0xd5, 0x68, 0xb6, 0x4b, 0x2b, 0x40, 0x0d, 0x6f, 0x6d, 0x02,
0xfe, 0x26, 0x76, 0x03, 0x2e, 0x40, 0x1e, 0x43, 0xd6, 0x60, 0xd3, 0x68, 0x9b, 0x0b, 0x9b, 0x03,
0x09, 0x6f, 0x89, 0x01, 0x89, 0x0c, 0x19, 0x43, 0xd1, 0x60, 0xe1, 0x68, 0xe2, 0x68, 0xfe, 0x23,
0x9a, 0x43, 0x0b, 0x40, 0x13, 0x43, 0x40, 0x21, 0x19, 0x43, 0xe1, 0x60, 0x61, 0x69, 0xbd, 0x4a,
0x0a, 0x40, 0x62, 0x61, 0x00, 0x21, 0x01, 0x61, 0x05, 0x21, 0x03, 0x20, 0xff, 0xf7, 0xd8, 0xfe,
0x00, 0x20, 0x70, 0xbd, 0x5d, 0x17, 0x00, 0x20, 0x00, 0x10, 0x00, 0x20, 0xff, 0xff, 0xe1, 0xff,
0xf4, 0xb5, 0x86, 0xb0, 0x80, 0x68, 0x05, 0x90, 0x88, 0x00, 0xd7, 0x49, 0x40, 0x18, 0x01, 0x90,
0x05, 0x98, 0x00, 0x6f, 0xc1, 0x06, 0xc9, 0x0e, 0x00, 0x91, 0x80, 0x01, 0x80, 0x0c, 0x04, 0x90,
0x10, 0x24, 0x04, 0x26, 0x01, 0x25, 0x65, 0x4f, 0xf8, 0x68, 0x80, 0x0b, 0x80, 0x03, 0x04, 0x99,
0x01, 0x43, 0xf9, 0x60, 0x38, 0x68, 0xa8, 0x49, 0x01, 0x40, 0x39, 0x60, 0x00, 0x98, 0x41, 0x02,
0x80, 0x00, 0x08, 0x43, 0x5b, 0x49, 0x09, 0x68, 0x5d, 0x4a, 0x0a, 0x40, 0x02, 0x43, 0x59, 0x48,
0x02, 0x60, 0x05, 0x21, 0x03, 0x20, 0xff, 0xf7, 0xa3, 0xfe, 0x00, 0xf0, 0xb9, 0xf8, 0x00, 0x28,
0x08, 0xd1, 0x38, 0x68, 0x9d, 0x49, 0x01, 0x40, 0xe0, 0x20, 0xc0, 0x00, 0x08, 0x43, 0x38, 0x60,
0x00, 0xf0, 0xe0, 0xf8, 0x00, 0x28, 0x0b, 0xd1, 0xf8, 0x68, 0x80, 0x0b, 0x80, 0x03, 0x04, 0x99,
0x09, 0x01, 0x01, 0x43, 0xf9, 0x60, 0x00, 0x99, 0x89, 0x1c, 0x03, 0xa8, 0x00, 0xf0, 0x58, 0xf8,
0x00, 0x28, 0x04, 0xd1, 0x00, 0x99, 0x89, 0x1e, 0x02, 0xa8, 0x00, 0xf0, 0x51, 0xf8, 0x00, 0x28,
0xc2, 0xd1, 0x06, 0x98, 0x03, 0x99, 0x02, 0x9a, 0x89, 0x1a, 0x88, 0x42, 0x0b, 0xd2, 0x01, 0x20,
0xb0, 0x40, 0x24, 0x1a, 0xe4, 0xb2, 0x3f, 0x48, 0x40, 0x68, 0x3f, 0x49, 0x01, 0x40, 0xe0, 0x02,
0x08, 0x43, 0x3c, 0x49, 0x48, 0x60, 0x01, 0x2e, 0x0c, 0xdb, 0x71, 0x1e, 0x01, 0x20, 0x88, 0x40,
0x24, 0x18, 0xe4, 0xb2, 0x37, 0x48, 0x40, 0x68, 0x37, 0x49, 0x01, 0x40, 0xe0, 0x02, 0x08, 0x43,
0x34, 0x49, 0x48, 0x60, 0x76, 0x1e, 0x76, 0xb2, 0x00, 0x2e, 0x9d, 0xd5, 0xb8, 0x69, 0x80, 0x03,
0x00, 0x0e, 0x01, 0x99, 0x09, 0x68, 0x05, 0x9a, 0xd2, 0x6e, 0xd2, 0x0a, 0x15, 0x40, 0x0e, 0xd1,
0xb2, 0x4a, 0x0a, 0x40, 0x61, 0x02, 0xf8, 0x23, 0x9b, 0x01, 0x0b, 0x40, 0x13, 0x43, 0x80, 0x03,
0xfc, 0x21, 0x09, 0x03, 0x01, 0x40, 0x19, 0x43, 0x01, 0x98, 0x01, 0x60, 0x09, 0xe0, 0xcb, 0x4a,
0x0a, 0x40, 0x21, 0x05, 0x11, 0x43, 0xc9, 0x01, 0xc9, 0x09, 0x40, 0x06, 0x08, 0x43, 0x01, 0x99,
0x08, 0x60, 0x00, 0x20, 0x07, 0xb0, 0xf0, 0xbd, 0x7f, 0xf8, 0x3f, 0xfc, 0x00, 0x01, 0xc0, 0x03,
0xf8, 0xb5, 0x07, 0x00, 0x00, 0x25, 0x1b, 0x48, 0x02, 0x68, 0x1d, 0x4b, 0x13, 0x40, 0x8a, 0x00,
0x1a, 0x43, 0x49, 0x02, 0x11, 0x43, 0x01, 0x60, 0x05, 0x21, 0x03, 0x20, 0xff, 0xf7, 0x20, 0xfe,
0xbb, 0x4c, 0x40, 0x20, 0x20, 0x82, 0x00, 0xbf, 0x00, 0xbf, 0x00, 0xbf, 0xb9, 0x4e, 0x20, 0x68,
0x30, 0x40, 0x20, 0x60, 0x20, 0x68, 0xf1, 0x43, 0x01, 0x43, 0x21, 0x60, 0x00, 0x23, 0x00, 0x22,
0x64, 0x21, 0x02, 0x20, 0xff, 0xf7, 0x1c, 0xfe, 0x02, 0x21, 0x40, 0x20, 0xff, 0xf7, 0x20, 0xfe,
0x20, 0x68, 0x06, 0x40, 0x26, 0x60, 0x02, 0x20, 0xff, 0xf7, 0x22, 0xfe, 0x20, 0x68, 0x41, 0x02,
0xc9, 0x0f, 0x00, 0xd1, 0x25, 0x25, 0x60, 0x68, 0x00, 0x03, 0x00, 0x0b, 0x38, 0x60, 0x28, 0x00,
0xf2, 0xbd, 0x00, 0x00, 0x28, 0x40, 0x00, 0x40, 0xff, 0x07, 0xff, 0xff, 0x2c, 0x42, 0x00, 0x40,
0x83, 0xc1, 0xff, 0xff, 0xff, 0xf8, 0xff, 0xff, 0x20, 0x40, 0x00, 0x40, 0x03, 0x00, 0x7e, 0x00,
0x70, 0xb5, 0x00, 0x25, 0xa0, 0x4e, 0xa1, 0x4c, 0x20, 0x68, 0x30, 0x40, 0x20, 0x60, 0x00, 0x23,
0x00, 0x22, 0xfa, 0x21, 0x49, 0x00, 0x02, 0x20, 0xff, 0xf7, 0xea, 0xfd, 0x10, 0x20, 0xa0, 0x82,
0x00, 0xbf, 0x00, 0xbf, 0x00, 0xbf, 0x20, 0x68, 0xe1, 0x0c, 0x01, 0x43, 0x21, 0x60, 0x02, 0x21,
0x10, 0x20, 0xff, 0xf7, 0xe5, 0xfd, 0x20, 0x68, 0x06, 0x40, 0x26, 0x60, 0x02, 0x20, 0xff, 0xf7,
0xe7, 0xfd, 0x20, 0x68, 0x41, 0x03, 0xc9, 0x0f, 0x00, 0xd1, 0x27, 0x25, 0x28, 0x00, 0x70, 0xbd,
0x80, 0xc1, 0x81, 0x01, 0xcf, 0x00, 0xff, 0xff, 0x30, 0x80, 0x00, 0x00, 0x01, 0x5a, 0x62, 0x02,
0xff, 0xff, 0xf3, 0xff, 0x38, 0xb5, 0x00, 0x24, 0x89, 0x4d, 0x04, 0x20, 0xa8, 0x83, 0x00, 0xbf,
0x00, 0xbf, 0x00, 0xbf, 0x28, 0x68, 0x80, 0x21, 0x01, 0x43, 0x29, 0x60, 0x00, 0x23, 0x00, 0x22,
0xfa, 0x21, 0x49, 0x00, 0x02, 0x20, 0xff, 0xf7, 0xb3, 0xfd, 0x02, 0x21, 0x04, 0x20, 0xff, 0xf7,
0xb7, 0xfd, 0x28, 0x68, 0x80, 0x21, 0x88, 0x43, 0x28, 0x60, 0x02, 0x20, 0xff, 0xf7, 0xb8, 0xfd,
0x28, 0x68, 0x41, 0x01, 0xc9, 0x0f, 0x00, 0xd1, 0x26, 0x24, 0x20, 0x00, 0x32, 0xbd, 0x00, 0x00,
0xff, 0x0f, 0xfc, 0xff, 0xff, 0x3f, 0xe0, 0xff, 0x70, 0xb5, 0x00, 0x24, 0x01, 0x25, 0x74, 0x4e,
0xb5, 0x83, 0x00, 0xbf, 0x00, 0xbf, 0x00, 0xbf, 0x30, 0x68, 0x80, 0x21, 0x01, 0x43, 0x31, 0x60,
0x00, 0x23, 0x00, 0x22, 0xfa, 0x21, 0x49, 0x00, 0x02, 0x20, 0xff, 0xf7, 0x89, 0xfd, 0x02, 0x21,
0x01, 0x20, 0xff, 0xf7, 0x8d, 0xfd, 0x30, 0x68, 0x80, 0x21, 0x88, 0x43, 0x30, 0x60, 0x02, 0x20,
0xff, 0xf7, 0x8e, 0xfd, 0x30, 0x68, 0xc0, 0x0a, 0x05, 0x40, 0x00, 0xd1, 0x29, 0x24, 0x20, 0x00,
0x70, 0xbd, 0x00, 0x00, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xf8, 0xbf, 0xff,
0xfe, 0xb5, 0x86, 0xb0, 0x87, 0x68, 0x02, 0x24, 0x84, 0x20, 0x38, 0x58, 0x80, 0x0c, 0x20, 0x40,
0x08, 0xd1, 0x1d, 0x4b, 0x81, 0x00, 0xbe, 0x22, 0x92, 0x00, 0x52, 0x58, 0x5a, 0x50, 0x40, 0x1c,
0x08, 0x28, 0xf7, 0xdb, 0x3f, 0x1d, 0x68, 0x46, 0xf9, 0x6e, 0x89, 0x01, 0x89, 0x0c, 0x01, 0x80,
0x54, 0x48, 0x00, 0x68, 0x00, 0x07, 0x80, 0x0f, 0x01, 0x25, 0x01, 0x28, 0x26, 0xd1, 0x01, 0x24,
0xfa, 0x22, 0x92, 0x00, 0x38, 0x68, 0x80, 0x01, 0x80, 0x09, 0x00, 0x21, 0xff, 0xf7, 0x40, 0xfd,
0x02, 0x90, 0x68, 0x46, 0x00, 0x88, 0x44, 0x43, 0x60, 0x00, 0x01, 0x90, 0xba, 0x6e, 0x04, 0xab,
0x90, 0x02, 0x80, 0x0d, 0x01, 0x99, 0x48, 0x43, 0x82, 0x21, 0x89, 0x01, 0x48, 0x43, 0x00, 0x21,
0x03, 0xc3, 0x02, 0x98, 0x44, 0x49, 0x48, 0x43, 0x03, 0x90, 0x0f, 0x20, 0xd1, 0x0a, 0x0d, 0x40,
0x08, 0xd1, 0x10, 0x40, 0x08, 0xe0, 0x00, 0xbf, 0x44, 0x08, 0x00, 0x20, 0x02, 0x28, 0xd7, 0xd0,
0x28, 0x20, 0x29, 0xe0, 0x11, 0x09, 0x08, 0x40, 0x07, 0x99, 0x08, 0x70, 0x00, 0x24, 0x0e, 0x9f,
0xa0, 0x00, 0x3a, 0x49, 0x40, 0x58, 0xc5, 0x05, 0xed, 0x0d, 0x1a, 0xd0, 0xa6, 0x00, 0x03, 0x9a,
0x00, 0x92, 0x28, 0x00, 0x00, 0x21, 0x04, 0xaa, 0x0c, 0xca, 0xff, 0xf7, 0x29, 0xfd, 0x00, 0x9a,
0xff, 0xf7, 0x06, 0xfd, 0x08, 0x99, 0x88, 0x51, 0x02, 0x9a, 0x01, 0x98, 0x68, 0x43, 0x30, 0x49,
0x48, 0x43, 0x00, 0x21, 0xff, 0xf7, 0xfc, 0xfc, 0xb8, 0x51, 0x64, 0x1c, 0xe4, 0xb2, 0x08, 0x2c,
0xde, 0xdb, 0x06, 0x98, 0x04, 0x70, 0x00, 0x20, 0x09, 0xb0, 0xf0, 0xbd, 0xff, 0x01, 0xf0, 0xff,
0x10, 0xb5, 0x84, 0x68, 0x02, 0x20, 0xff, 0xf7, 0x03, 0xfd, 0x21, 0x48, 0xc1, 0x6d, 0x01, 0x22,
0x91, 0x43, 0xc1, 0x65, 0x23, 0x49, 0x8a, 0x68, 0x23, 0x4b, 0x13, 0x40, 0x8b, 0x60, 0x4a, 0x69,
0x22, 0x4b, 0x13, 0x40, 0x4b, 0x61, 0xca, 0x68, 0x21, 0x4b, 0x13, 0x40, 0xcb, 0x60, 0x0a, 0x68,
0x20, 0x4b, 0x13, 0x40, 0x0b, 0x60, 0x4a, 0x68, 0x1f, 0x4b, 0x13, 0x40, 0x4b, 0x60, 0x4a, 0x69,
0x1c, 0x23, 0x9a, 0x43, 0x4a, 0x61, 0x22, 0x6f, 0x03, 0x68, 0x1c, 0x4c, 0x1c, 0x40, 0x53, 0x0f,
0x1b, 0x02, 0x23, 0x43, 0xd2, 0x08, 0xe0, 0x24, 0xa4, 0x04, 0x14, 0x40, 0x1c, 0x43, 0x04, 0x60,
0xc2, 0x68, 0x08, 0x4b, 0x13, 0x40, 0xc3, 0x60, 0x8a, 0x68, 0x15, 0x4b, 0x13, 0x40, 0x8b, 0x60,
0x81, 0x68, 0x05, 0x4a, 0x0a, 0x40, 0x82, 0x60, 0x10, 0xbd, 0x00, 0x00, 0xff, 0xff, 0x0f, 0xfe,
0x38, 0x42, 0x00, 0x40, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x34, 0x42, 0x00, 0x40,
0x2c, 0x42, 0x00, 0x40, 0x70, 0x42, 0x00, 0x40, 0x20, 0xcb, 0x00, 0x00, 0x44, 0x08, 0x00, 0x20,
0x88, 0x13, 0x00, 0x00, 0x20, 0x40, 0x00, 0x40, 0x7f, 0x3e, 0x7e, 0x00, 0xff, 0xff, 0xe3, 0xff,
0x00, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0x7f, 0xf8, 0x3f, 0xfc,
0xff, 0xff, 0xbf, 0xff, 0x38, 0xb5, 0xa5, 0x4c, 0x22, 0x68, 0xa5, 0x4b, 0x13, 0x40, 0x23, 0x60,
0xa4, 0x4a, 0x13, 0x68, 0xad, 0x4d, 0x1d, 0x40, 0x00, 0x02, 0x28, 0x43, 0x10, 0x60, 0x03, 0x20,
0xff, 0xf7, 0x76, 0xfc, 0x40, 0x20, 0x20, 0x82, 0x00, 0xbf, 0x00, 0xbf, 0x00, 0xbf, 0x20, 0x68,
0x80, 0x21, 0x89, 0x03, 0x01, 0x43, 0x21, 0x60, 0x00, 0x23, 0x00, 0x22, 0x32, 0x21, 0x02, 0x20,
0xff, 0xf7, 0x76, 0xfc, 0x02, 0x21, 0x40, 0x20, 0xff, 0xf7, 0x7a, 0xfc, 0x02, 0x20, 0xff, 0xf7,
0x7f, 0xfc, 0x60, 0x68, 0x00, 0x03, 0x00, 0x0b, 0x32, 0xbd, 0x70, 0xb5, 0x86, 0x68, 0x9c, 0x49,
0x01, 0x61, 0x9c, 0x4c, 0xa0, 0x69, 0x9c, 0x49, 0x01, 0x40, 0x80, 0x20, 0xc0, 0x04, 0x08, 0x43,
0xa0, 0x61, 0x60, 0x69, 0x99, 0x49, 0x01, 0x40, 0xf0, 0x20, 0x00, 0x01, 0x08, 0x43, 0x60, 0x61,
0x86, 0x4d, 0xe8, 0x6e, 0xe1, 0x0b, 0x01, 0x43, 0xe9, 0x66, 0x20, 0x69, 0xc0, 0x21, 0x89, 0x04,
0x01, 0x43, 0x21, 0x61, 0xa0, 0x69, 0x92, 0x49, 0x01, 0x40, 0x92, 0x48, 0x08, 0x43, 0xa0, 0x61,
0x05, 0x21, 0x03, 0x20, 0xff, 0xf7, 0x34, 0xfc, 0xa0, 0x69, 0x04, 0x21, 0x88, 0x43, 0xa0, 0x61,
0x0a, 0x21, 0x03, 0x20, 0xff, 0xf7, 0x2c, 0xfc, 0x70, 0x68, 0x80, 0x01, 0x80, 0x09, 0x8a, 0x49,
0x88, 0x42, 0x01, 0xda, 0x00, 0x20, 0x01, 0xe0, 0x80, 0x20, 0x00, 0x03, 0x21, 0x68, 0xd1, 0x4a,
0x0a, 0x40, 0x10, 0x43, 0xb0, 0x21, 0x49, 0x03, 0x01, 0x43, 0x21, 0x60, 0x28, 0x68, 0x80, 0x0b,
0x80, 0x03, 0xb1, 0x6f, 0x49, 0x01, 0x89, 0x0c, 0x01, 0x43, 0x29, 0x60, 0x28, 0x6d, 0x02, 0x21,
0x01, 0x43, 0x29, 0x65, 0x70, 0xbd, 0xf0, 0xb5, 0x83, 0xb0, 0x81, 0x68, 0x01, 0x91, 0x00, 0x25,
0x00, 0x26, 0x81, 0x79, 0x20, 0x22, 0x0a, 0x43, 0x82, 0x71, 0x01, 0x9c, 0x24, 0x1d, 0x61, 0x68,
0x48, 0x08, 0x76, 0x4a, 0x91, 0x42, 0x01, 0xd3, 0x06, 0x21, 0x05, 0xe0, 0x52, 0x08, 0x91, 0x42,
0x01, 0xd2, 0x1e, 0x21, 0x00, 0xe0, 0x0c, 0x21, 0x05, 0x22, 0x48, 0x43, 0x00, 0x21, 0xff, 0xf7,
0xf7, 0xfb, 0x21, 0x68, 0x8a, 0x01, 0x92, 0x09, 0x06, 0x21, 0x4a, 0x43, 0x17, 0x00, 0x40, 0x00,
0x00, 0x21, 0x62, 0x6f, 0x52, 0x01, 0x92, 0x0c, 0x00, 0x23, 0xff, 0xf7, 0x09, 0xfc, 0x00, 0x18,
0x49, 0x41, 0x3a, 0x00, 0xff, 0xf7, 0xe4, 0xfb, 0x00, 0x90, 0x52, 0x4f, 0x38, 0x68, 0xae, 0x49,
0x01, 0x40, 0x28, 0x04, 0x08, 0x43, 0x38, 0x60, 0x60, 0x6f, 0xc1, 0x06, 0xc9, 0x0e, 0xc0, 0x05,
0x00, 0x0f, 0xff, 0xf7, 0x47, 0xff, 0x00, 0x99, 0x88, 0x42, 0x03, 0xd3, 0x6d, 0x1c, 0xed, 0xb2,
0x10, 0x2d, 0xeb, 0xdb, 0x20, 0x68, 0x82, 0x01, 0x92, 0x09, 0x06, 0x20, 0x42, 0x43, 0x15, 0x00,
0x20, 0x6f, 0x00, 0x04, 0x00, 0x0e, 0x00, 0x21, 0x62, 0x6f, 0x52, 0x01, 0x92, 0x0c, 0x00, 0x23,
0xff, 0xf7, 0xde, 0xfb, 0x9d, 0x4a, 0x00, 0x23, 0xff, 0xf7, 0xda, 0xfb, 0x2a, 0x00, 0xff, 0xf7,
0xb7, 0xfb, 0xc8, 0x22, 0xd5, 0x00, 0xc1, 0x17, 0x62, 0x6f, 0xd2, 0x04, 0x12, 0x0f, 0x23, 0x6f,
0x1b, 0x06, 0x1b, 0x0f, 0xd2, 0x1a, 0xd3, 0x17, 0xff, 0xf7, 0xca, 0xfb, 0xb9, 0x22, 0x00, 0x23,
0xff, 0xf7, 0xc6, 0xfb, 0x2a, 0x00, 0xff, 0xf7, 0xa3, 0xfb, 0x00, 0x90, 0x38, 0x68, 0x90, 0x49,
0x01, 0x40, 0x30, 0x06, 0x08, 0x43, 0x38, 0x60, 0x74, 0x20, 0x20, 0x5c, 0xc1, 0x06, 0xc9, 0x0e,
0x20, 0x6f, 0x00, 0x06, 0x00, 0x0f, 0xff, 0xf7, 0x05, 0xff, 0x05, 0x00, 0x60, 0x6f, 0xc1, 0x06,
0xc9, 0x0e, 0xc0, 0x04, 0x00, 0x0f, 0xff, 0xf7, 0xfd, 0xfe, 0x40, 0x1b, 0x00, 0x99, 0x81, 0x42,
0x03, 0xdb, 0x76, 0x1c, 0xf6, 0xb2, 0x08, 0x2e, 0xe0, 0xdb, 0x38, 0x68, 0x2b, 0x49, 0x01, 0x40,
0xf8, 0x0c, 0x08, 0x43, 0x38, 0x60, 0x38, 0x68, 0x00, 0x01, 0x00, 0x0f, 0x01, 0x99, 0x82, 0x22,
0x52, 0x00, 0x89, 0x18, 0x0a, 0x68, 0x0f, 0x23, 0x9a, 0x43, 0x10, 0x43, 0x08, 0x60, 0x3a, 0x68,
0x92, 0x02, 0x92, 0x0e, 0x77, 0x4b, 0x03, 0x40, 0x10, 0x01, 0x18, 0x43, 0x08, 0x60, 0xf7, 0xbd,
0x10, 0xb5, 0x04, 0x21, 0x74, 0x4a, 0x11, 0x60, 0x1e, 0x49, 0x0a, 0x68, 0x6d, 0x4b, 0x13, 0x40,
0x0b, 0x60, 0x0e, 0x4a, 0xd3, 0x6e, 0x71, 0x4c, 0x1c, 0x40, 0xd4, 0x66, 0x0b, 0x69, 0x70, 0x4c,
0x1c, 0x40, 0x0c, 0x61, 0x8b, 0x69, 0x03, 0x24, 0xa3, 0x43, 0x8b, 0x61, 0x4b, 0x69, 0x17, 0x4c,
0x1c, 0x40, 0x4c, 0x61, 0x11, 0x68, 0x06, 0x4b, 0x0b, 0x40, 0x13, 0x60, 0x11, 0x6d, 0x02, 0x23,
0x99, 0x43, 0x11, 0x65, 0x00, 0x21, 0x01, 0x61, 0x10, 0xbd, 0x00, 0x00, 0x38, 0x42, 0x00, 0x40,
0xff, 0xff, 0xdf, 0xff, 0x4c, 0x40, 0x00, 0x40, 0x62, 0x48, 0x01, 0x68, 0x62, 0x4a, 0x0a, 0x40,
0x02, 0x60, 0x01, 0x6b, 0x61, 0x4a, 0x0a, 0x40, 0x02, 0x63, 0x41, 0x6b, 0x01, 0x22, 0x91, 0x43,
0x41, 0x63, 0xc1, 0x6a, 0x5e, 0x4a, 0x0a, 0x40, 0xc2, 0x62, 0x70, 0x47, 0xff, 0xf0, 0xff, 0xff,
0x6d, 0x1a, 0x00, 0x20, 0x34, 0x40, 0x00, 0x40, 0xff, 0xff, 0xc0, 0xf0, 0xff, 0x80, 0xff, 0xff,
0xf8, 0xf0, 0xff, 0xff, 0x07, 0x08, 0x00, 0x00, 0x00, 0x5a, 0x62, 0x02, 0x01, 0x27, 0xb9, 0x29,
0xf8, 0xb5, 0x02, 0x00, 0x08, 0x00, 0x95, 0x68, 0x01, 0x27, 0x52, 0x49, 0x88, 0x42, 0x01, 0xd3,
0x01, 0x23, 0x05, 0xe0, 0x49, 0x08, 0x88, 0x42, 0x01, 0xd2, 0x0b, 0x23, 0x00, 0xe0, 0x04, 0x23,
0x48, 0x4c, 0x21, 0x6b, 0x4c, 0x4a, 0x0a, 0x40, 0xd9, 0x02, 0x11, 0x43, 0x21, 0x63, 0x69, 0x68,
0x89, 0x01, 0x89, 0x09, 0x49, 0x08, 0x8a, 0x00, 0x56, 0x18, 0x01, 0x0a, 0x00, 0x06, 0x00, 0xbf,
0x4f, 0xa2, 0xd2, 0x5c, 0x00, 0x23, 0xff, 0xf7, 0x13, 0xfb, 0x32, 0x00, 0xff, 0xf7, 0xf0, 0xfa,
0xa0, 0x62, 0x80, 0x20, 0x41, 0x49, 0x08, 0x80, 0x00, 0xbf, 0x00, 0xbf, 0x00, 0xbf, 0x20, 0x68,
0x39, 0x07, 0x01, 0x43, 0x21, 0x60, 0x64, 0x21, 0x03, 0x20, 0xff, 0xf7, 0xd9, 0xfa, 0x28, 0x00,
0x88, 0x30, 0xc0, 0x6f, 0x0f, 0x26, 0x62, 0x6b, 0x39, 0x49, 0x11, 0x40, 0x0f, 0x22, 0x02, 0x40,
0x12, 0x06, 0x0a, 0x43, 0x00, 0x03, 0xfc, 0x21, 0x89, 0x03, 0x01, 0x40, 0x11, 0x43, 0x61, 0x63,
0x20, 0x6b, 0x34, 0x49, 0x01, 0x40, 0x34, 0x48, 0x08, 0x43, 0x20, 0x63, 0x60, 0x6b, 0x38, 0x43,
0x60, 0x63, 0xe0, 0x6a, 0x31, 0x49, 0x01, 0x40, 0x31, 0x48, 0x08, 0x43, 0xe0, 0x62, 0xe0, 0x6a,
0x30, 0x49, 0x01, 0x43, 0xe1, 0x62, 0x00, 0x23, 0x00, 0x22, 0xfa, 0x21, 0x49, 0x00, 0x02, 0x20,
0xff, 0xf7, 0xbe, 0xfa, 0x02, 0x21, 0x80, 0x20, 0xff, 0xf7, 0xc2, 0xfa, 0x02, 0x20, 0xff, 0xf7,
0xc7, 0xfa, 0xe0, 0x6a, 0x80, 0x0f, 0x07, 0x40, 0x01, 0xd1, 0x14, 0x20, 0xf2, 0xbd, 0xa0, 0x6b,
0xc0, 0x21, 0xc9, 0x00, 0x01, 0x43, 0xa1, 0x63, 0x20, 0x6b, 0x23, 0x49, 0x01, 0x40, 0x28, 0x1d,
0x00, 0x6f, 0x06, 0x40, 0xf0, 0x03, 0x08, 0x43, 0x20, 0x63, 0x88, 0x35, 0x28, 0x68, 0xa1, 0x6b,
0x1e, 0x4a, 0x0a, 0x40, 0x41, 0x07, 0x89, 0x0c, 0x11, 0x43, 0xc2, 0x04, 0x80, 0x23, 0xdb, 0x03,
0x1a, 0x40, 0x0a, 0x43, 0x80, 0x09, 0x3c, 0x21, 0x01, 0x40, 0x11, 0x43, 0xa1, 0x63, 0x00, 0x20,
0xf2, 0xbd, 0x00, 0x00, 0xff, 0xff, 0xe0, 0xff, 0xff, 0xff, 0xc0, 0xff, 0x80, 0x84, 0x1e, 0x00,
0xff, 0xff, 0xff, 0xf0, 0x0f, 0xfc, 0xff, 0xff, 0x80, 0xe1, 0x00, 0xe0, 0xff, 0x7f, 0xff, 0xff,
0xff, 0xff, 0xff, 0xfc, 0x18, 0x40, 0x00, 0x40, 0xff, 0xff, 0xff, 0xef, 0xbc, 0xfc, 0xff, 0xff,
0xfe, 0xff, 0xfc, 0xff, 0x01, 0x27, 0xb9, 0x29, 0xff, 0x87, 0xff, 0xff, 0x48, 0x42, 0x00, 0x40,
0xff, 0xff, 0xc0, 0xf0, 0x0c, 0xfc, 0xff, 0xff, 0x43, 0x03, 0x00, 0x00, 0x3f, 0xfc, 0xfa, 0xff,
0x80, 0x02, 0x01, 0x00, 0x01, 0x00, 0x02, 0x00, 0xff, 0x7f, 0xf8, 0xff, 0xc3, 0xc7, 0xbf, 0xff,
0x00, 0x06, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x12, 0x18, 0x1e, 0x10, 0xb5, 0x01, 0x68,
0x8c, 0x31, 0x09, 0x68, 0x09, 0x02, 0x09, 0x0e, 0x81, 0x4a, 0x0e, 0x23, 0xc3, 0x5e, 0x13, 0x40,
0x10, 0x24, 0x00, 0x5f, 0x02, 0x40, 0x10, 0x04, 0x18, 0x43, 0x7e, 0x4a, 0x10, 0x60, 0x89, 0x01,
0x03, 0x20, 0xff, 0xf7, 0x35, 0xfa, 0x10, 0xbd, 0x10, 0xb5, 0x04, 0x00, 0xff, 0xf7, 0xe6, 0xff,
0x61, 0x68, 0x89, 0xb2, 0x60, 0x8a, 0xc0, 0xb2, 0x00, 0xf0, 0x35, 0xfa, 0x80, 0x08, 0x10, 0xbd,
0x10, 0xb5, 0x04, 0x00, 0xa0, 0x68, 0x74, 0x49, 0x21, 0x61, 0x00, 0x22, 0x88, 0x30, 0x00, 0x68,
0xc0, 0x01, 0xc1, 0x0f, 0x20, 0x00, 0x00, 0xf0, 0x7d, 0xfa, 0x00, 0x28, 0x01, 0xd0, 0x80, 0x00,
0xe0, 0x71, 0x10, 0xbd, 0x80, 0xb5, 0x00, 0xf0, 0x0d, 0xfa, 0x01, 0xbd, 0xf0, 0xb5, 0x87, 0xb0,
0x85, 0x68, 0x20, 0x21, 0x82, 0x79, 0x20, 0x23, 0x13, 0x43, 0x83, 0x71, 0x00, 0x95, 0x88, 0x35,
0x28, 0x68, 0x6c, 0x46, 0x02, 0x02, 0x92, 0x0f, 0x91, 0x40, 0x21, 0x81, 0x00, 0x21, 0x61, 0x81,
0xe1, 0x60, 0x21, 0x82, 0xc0, 0x0f, 0x60, 0x75, 0x28, 0x79, 0x60, 0x82, 0x28, 0x68, 0x80, 0x03,
0x00, 0x0f, 0x20, 0x75, 0x5d, 0x48, 0x01, 0x90, 0x5d, 0x4a, 0xff, 0xf7, 0xf9, 0xf9, 0x01, 0x90,
0x28, 0x68, 0xc0, 0x00, 0x40, 0x0f, 0x56, 0x4e, 0x01, 0x28, 0x02, 0xd0, 0x02, 0x28, 0x04, 0xd0,
0x07, 0xe0, 0x68, 0x46, 0x00, 0xf0, 0x47, 0xf8, 0x26, 0xe0, 0x68, 0x46, 0x00, 0xf0, 0x43, 0xf8,
0x14, 0xe0, 0x2a, 0x6f, 0x31, 0x00, 0x11, 0x40, 0x61, 0x81, 0x13, 0x0c, 0x32, 0x00, 0x1a, 0x40,
0xa2, 0x81, 0x50, 0x4b, 0x80, 0x27, 0xbf, 0x00, 0xb9, 0x42, 0x01, 0xdb, 0xc9, 0x18, 0x61, 0x81,
0xba, 0x42, 0x01, 0xdb, 0xd1, 0x18, 0xa1, 0x81, 0x03, 0x28, 0x03, 0xd1, 0x68, 0x46, 0x00, 0xf0,
0xf9, 0xf8, 0x09, 0xe0, 0x0a, 0x20, 0x20, 0x5e, 0x30, 0x40, 0x0c, 0x21, 0x61, 0x5e, 0x31, 0x40,
0x09, 0x04, 0x01, 0x43, 0x3f, 0x48, 0x01, 0x60, 0x28, 0x68, 0x41, 0x00, 0xc9, 0x0f, 0x09, 0xd0,
0x68, 0x68, 0x61, 0x89, 0x02, 0x04, 0x12, 0x0e, 0x89, 0x18, 0x61, 0x81, 0xa1, 0x89, 0x00, 0x0e,
0x08, 0x18, 0xa0, 0x81, 0x28, 0x6f, 0x00, 0x0b, 0x00, 0x03, 0x0a, 0x21, 0x61, 0x5e, 0x31, 0x40,
0x01, 0x43, 0x39, 0x48, 0x08, 0x40, 0x0c, 0x21, 0x61, 0x5e, 0x0e, 0x40, 0x31, 0x04, 0x01, 0x43,
0x29, 0x67, 0x07, 0xb0, 0xf0, 0xbd, 0xf8, 0xb5, 0x04, 0x00, 0x00, 0x20, 0x00, 0x90, 0x00, 0x27,
0x20, 0x00, 0xff, 0xf7, 0x61, 0xff, 0x05, 0x00, 0x22, 0xe0, 0x21, 0x89, 0x00, 0x9a, 0x10, 0x18,
0xe0, 0x81, 0x78, 0x18, 0x20, 0x82, 0x20, 0x00, 0xff, 0xf7, 0x56, 0xff, 0xa8, 0x42, 0x04, 0xd2,
0x05, 0x00, 0xe0, 0x89, 0x60, 0x81, 0x20, 0x8a, 0xa0, 0x81, 0x76, 0x1c, 0x04, 0x2e, 0x1d, 0xdb,
0x0a, 0x20, 0x20, 0x5e, 0x00, 0x90, 0x0c, 0x20, 0x27, 0x5e, 0x20, 0x89, 0x40, 0x08, 0x20, 0x81,
0x60, 0x8a, 0x40, 0x00, 0x60, 0x82, 0x80, 0xb2, 0x11, 0x28, 0x01, 0xdb, 0x10, 0x20, 0x60, 0x82,
0x20, 0x68, 0x88, 0x30, 0x00, 0x68, 0xc1, 0x02, 0xc9, 0x0f, 0x01, 0xd0, 0x08, 0x20, 0x00, 0xe0,
0x04, 0x20, 0x21, 0x89, 0x81, 0x42, 0x0e, 0xd3, 0x00, 0x26, 0x01, 0xe0, 0x02, 0x2e, 0x01, 0xda,
0x20, 0x89, 0x01, 0xe0, 0x21, 0x89, 0x48, 0x42, 0x00, 0x2e, 0xc6, 0xd0, 0x03, 0x2e, 0xc4, 0xda,
0x22, 0x89, 0x51, 0x42, 0xc2, 0xe7, 0xf1, 0xbd, 0x30, 0xb5, 0x00, 0x22, 0x82, 0x5e, 0x0c, 0x00,
0x07, 0xd4, 0x0e, 0x4d, 0x6c, 0x1a, 0x94, 0x42, 0x07, 0xdb, 0x51, 0x18, 0x01, 0x80, 0x00, 0x20,
0x30, 0xbd, 0x0b, 0x4d, 0x6c, 0x1a, 0xa2, 0x42, 0xf7, 0xda, 0x01, 0x20, 0x30, 0xbd, 0x00, 0x00,
0xff, 0x0f, 0x00, 0x00, 0x28, 0x42, 0x00, 0x40, 0xf9, 0x10, 0x00, 0x00, 0x00, 0x48, 0xe8, 0x01,
0x62, 0x3d, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0xff, 0x00, 0xf0, 0xff, 0x01, 0x00, 0x00,
0x01, 0xfe, 0xff, 0xff, 0xf2, 0xb5, 0x82, 0xb0, 0x04, 0x00, 0x60, 0x89, 0xe0, 0x81, 0xa0, 0x89,
0x20, 0x82, 0x21, 0x68, 0x88, 0x31, 0x08, 0x68, 0x00, 0x03, 0x80, 0x0f, 0x01, 0xd0, 0x20, 0x20,
0x00, 0xe0, 0x10, 0x20, 0x60, 0x82, 0x02, 0x98, 0x00, 0x28, 0x02, 0xd0, 0x20, 0x00, 0x10, 0x30,
0x01, 0xe0, 0x20, 0x00, 0x0e, 0x30, 0x00, 0x90, 0x08, 0x68, 0xc1, 0x02, 0xc9, 0x0f, 0x01, 0xd0,
0x2c, 0x25, 0x00, 0xe0, 0x10, 0x25, 0x69, 0x42, 0x09, 0xb2, 0x00, 0x98, 0xff, 0xf7, 0xb4, 0xff,
0x00, 0x28, 0x07, 0xd0, 0x10, 0x25, 0x0f, 0x21, 0xc9, 0x43, 0x00, 0x98, 0xff, 0xf7, 0xac, 0xff,
0x00, 0x28, 0x2e, 0xd1, 0x00, 0x98, 0x00, 0x21, 0x47, 0x5e, 0x20, 0x00, 0xff, 0xf7, 0xc4, 0xfe,
0x01, 0x90, 0x18, 0x21, 0x00, 0x98, 0xff, 0xf7, 0x9f, 0xff, 0x00, 0x28, 0x21, 0xd1, 0xad, 0x08,
0x19, 0x26, 0x20, 0x00, 0xff, 0xf7, 0xb8, 0xfe, 0x01, 0x99, 0x88, 0x42, 0x06, 0xd3, 0x00, 0x98,
0x00, 0x88, 0x40, 0x1b, 0x00, 0x99, 0x08, 0x80, 0x6d, 0x08, 0x07, 0xd0, 0x29, 0xb2, 0x00, 0x98,
0xff, 0xf7, 0x8a, 0xff, 0x00, 0x28, 0x0c, 0xd1, 0x76, 0x1e, 0xea, 0xd1, 0x00, 0x98, 0x00, 0x21,
0x40, 0x5e, 0x38, 0x18, 0x40, 0x10, 0x02, 0x99, 0x00, 0x29, 0x01, 0xd0, 0xa0, 0x81, 0xf7, 0xbd,
0x60, 0x81, 0xf7, 0xbd, 0x10, 0xb5, 0x04, 0x00, 0x00, 0x21, 0xff, 0xf7, 0x9b, 0xff, 0x01, 0x21,
0x20, 0x00, 0xff, 0xf7, 0x97, 0xff, 0x10, 0xbd, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0x7d, 0x34, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0xb3, 0x2c, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0xa5, 0x2a, 0x00, 0x00, 0x80, 0xb5, 0x00, 0x22, 0xff, 0xf7, 0xe4, 0xff,
0x65, 0x49, 0x08, 0x70, 0x08, 0x71, 0x08, 0x72, 0x08, 0x73, 0x64, 0x49, 0x03, 0x20, 0xff, 0xf7,
0x9f, 0xf8, 0x1e, 0x21, 0x04, 0x20, 0x00, 0xf0, 0xa6, 0xf8, 0x80, 0xb2, 0x02, 0xbd, 0xf2, 0xb5,
0x87, 0x68, 0x5f, 0x4c, 0x20, 0x68, 0x1f, 0x21, 0x88, 0x43, 0x20, 0x60, 0x0f, 0x21, 0x03, 0x20,
0xff, 0xf7, 0x8e, 0xf8, 0x00, 0x20, 0x81, 0x00, 0x5a, 0x4a, 0x52, 0x58, 0x62, 0x50, 0x40, 0x1c,
0x06, 0x28, 0xf8, 0xdb, 0x0f, 0x21, 0x03, 0x20, 0xff, 0xf7, 0x82, 0xf8, 0x20, 0x68, 0x1f, 0x21,
0x01, 0x43, 0x21, 0x60, 0x80, 0x25, 0xad, 0x02, 0x29, 0x00, 0x94, 0x20, 0xff, 0xf7, 0xcc, 0xff,
0x04, 0x00, 0x29, 0x00, 0xc4, 0x20, 0xff, 0xf7, 0xc7, 0xff, 0x24, 0x1a, 0x24, 0xb2, 0x4e, 0x4d,
0x4e, 0x48, 0x60, 0x43, 0x80, 0x10, 0x46, 0x19, 0xec, 0x37, 0x38, 0x68, 0x80, 0x0c, 0x80, 0x04,
0xb1, 0x03, 0x89, 0x0b, 0x01, 0x43, 0x39, 0x60, 0x31, 0x00, 0x94, 0x20, 0xff, 0xf7, 0xb4, 0xff,
0x07, 0x00, 0x31, 0x00, 0xc4, 0x20, 0xff, 0xf7, 0xaf, 0xff, 0x38, 0x1a, 0x00, 0xb2, 0x44, 0x49,
0x8e, 0x42, 0x02, 0xd2, 0x20, 0x1a, 0x43, 0x49, 0x04, 0xe0, 0x43, 0x49, 0x8e, 0x42, 0x04, 0xd3,
0x20, 0x18, 0x42, 0x49, 0x48, 0x43, 0x80, 0x10, 0x46, 0x19, 0x41, 0x48, 0x86, 0x42, 0x03, 0xd3,
0x70, 0x00, 0x40, 0x49, 0x46, 0x18, 0x06, 0xe0, 0x3f, 0x48, 0x86, 0x42, 0x03, 0xd2, 0x3f, 0x48,
0x30, 0x18, 0x80, 0x08, 0x36, 0x18, 0x00, 0x98, 0x06, 0x60, 0x00, 0x20, 0xf2, 0xbd, 0x10, 0xb5,
0x04, 0x00, 0xa0, 0x68, 0x3a, 0x49, 0x21, 0x61, 0x01, 0x22, 0x88, 0x30, 0x00, 0x68, 0xc0, 0x01,
0xc1, 0x0f, 0x20, 0x00, 0x00, 0xf0, 0x8e, 0xf8, 0x00, 0x28, 0x01, 0xd0, 0x80, 0x00, 0xe0, 0x71,
0x10, 0xbd, 0x38, 0xb5, 0x04, 0x00, 0xa5, 0x68, 0xa0, 0x79, 0x20, 0x21, 0x01, 0x43, 0xa1, 0x71,
0x69, 0x46, 0x20, 0x00, 0xff, 0xf7, 0x83, 0xff, 0xec, 0x35, 0x2e, 0x49, 0x00, 0x28, 0x05, 0xd0,
0x80, 0x00, 0xe0, 0x71, 0x28, 0x68, 0x01, 0x40, 0x01, 0x20, 0x04, 0xe0, 0x28, 0x68, 0x01, 0x40,
0x00, 0x98, 0x80, 0x03, 0x80, 0x0b, 0x08, 0x43, 0x28, 0x60, 0x31, 0xbd, 0x80, 0xb5, 0x00, 0xf0,
0x01, 0xf8, 0x01, 0xbd, 0x10, 0xb5, 0x04, 0x00, 0x04, 0x20, 0x23, 0x49, 0x08, 0x60, 0x20, 0x00,
0xff, 0xf7, 0xca, 0xfc, 0x20, 0x00, 0xff, 0xf7, 0x3f, 0xff, 0x20, 0x00, 0xff, 0xf7, 0x44, 0xff,
0x00, 0x20, 0x20, 0x61, 0x10, 0xbd, 0xf8, 0xb5, 0x06, 0x00, 0x0f, 0x00, 0x00, 0x24, 0x00, 0x25,
0x0a, 0xe0, 0x39, 0x00, 0x03, 0x20, 0xfe, 0xf7, 0xeb, 0xff, 0x18, 0x48, 0x00, 0x68, 0x80, 0x0a,
0x17, 0x49, 0x01, 0x40, 0x64, 0x18, 0x6d, 0x1c, 0xb5, 0x42, 0xf2, 0xd3, 0x32, 0x00, 0x20, 0x00,
0x00, 0x21, 0xfe, 0xf7, 0xe5, 0xff, 0xf2, 0xbd, 0x5c, 0x40, 0x00, 0x40, 0xca, 0x08, 0x00, 0x00,
0x54, 0x40, 0x00, 0x40, 0x0c, 0x06, 0x00, 0x20, 0x7c, 0x01, 0x02, 0x00, 0x7f, 0xfe, 0xff, 0xff,
0xd7, 0xa3, 0x01, 0x00, 0x91, 0xfe, 0xff, 0xff, 0x34, 0x33, 0x02, 0x00, 0xab, 0xfe, 0xff, 0xff,
0x01, 0x80, 0x02, 0x00, 0x00, 0x80, 0xfd, 0xff, 0x39, 0xa9, 0x01, 0x00, 0xc7, 0x56, 0xfe, 0xff,
0xf9, 0x10, 0x00, 0x00, 0x00, 0x00, 0xfc, 0xff, 0x80, 0xe1, 0x00, 0xe0, 0xe0, 0x41, 0x00, 0x40,
0xfc, 0x07, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x13, 0x2b, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0xf1, 0x31, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x6d, 0x31, 0x00, 0x00, 0xf7, 0xb5, 0x06, 0x00, 0xb7, 0x68, 0xff, 0xf7, 0xe3, 0xff, 0x04, 0x00,
0x68, 0x46, 0x01, 0x7a, 0x30, 0x00, 0x00, 0xf0, 0xb8, 0xf8, 0x68, 0x46, 0x01, 0x7a, 0x30, 0x00,
0x00, 0xf0, 0x8e, 0xf8, 0x30, 0x00, 0xff, 0xf7, 0xdd, 0xff, 0x68, 0x46, 0x01, 0x7a, 0x30, 0x00,
0x00, 0xf0, 0x00, 0xf9, 0x01, 0x20, 0xff, 0xf7, 0xdd, 0xff, 0x38, 0x00, 0x14, 0x30, 0x34, 0x4d,
0x01, 0x78, 0xc9, 0x07, 0x18, 0xd4, 0xa9, 0x69, 0x32, 0x4a, 0x0a, 0x40, 0xaa, 0x61, 0x32, 0x49,
0x0b, 0x68, 0x32, 0x4a, 0x1a, 0x40, 0x50, 0x30, 0x00, 0x78, 0x40, 0x07, 0xc0, 0x0a, 0x10, 0x43,
0x30, 0x22, 0x02, 0x43, 0x0a, 0x60, 0xa8, 0x69, 0x0f, 0x22, 0x02, 0x43, 0xaa, 0x61, 0xc8, 0x6f,
0xd1, 0x22, 0x52, 0x01, 0x02, 0x43, 0xca, 0x67, 0x68, 0x46, 0x00, 0x7a, 0x00, 0x28, 0x1f, 0xd1,
0x28, 0x68, 0x1f, 0x21, 0x88, 0x43, 0x28, 0x60, 0x0f, 0x21, 0x03, 0x20, 0xfe, 0xf7, 0x58, 0xff,
0x00, 0x20, 0x81, 0x00, 0x22, 0x4a, 0x52, 0x58, 0x6a, 0x50, 0x40, 0x1c, 0x06, 0x28, 0xf8, 0xdb,
0xec, 0x37, 0x39, 0x68, 0x1f, 0x48, 0x01, 0x42, 0x02, 0xd0, 0x08, 0x40, 0x00, 0xf0, 0x13, 0xf9,
0x0f, 0x21, 0x03, 0x20, 0xfe, 0xf7, 0x44, 0xff, 0x28, 0x68, 0x1f, 0x21, 0x01, 0x43, 0x29, 0x60,
0x68, 0x46, 0x00, 0x79, 0x00, 0x28, 0x05, 0xd1, 0x68, 0x46, 0x01, 0x7a, 0x30, 0x00, 0x00, 0xf0,
0x03, 0xf8, 0x04, 0x00, 0x20, 0x00, 0xfe, 0xbd, 0x10, 0xb5, 0x83, 0x68, 0xda, 0x69, 0x94, 0x03,
0xe4, 0x0f, 0x11, 0x4a, 0x01, 0x29, 0x03, 0xd1, 0x00, 0x2c, 0x08, 0xd0, 0x0f, 0x4a, 0x01, 0xe0,
0x00, 0x2c, 0x04, 0xd0, 0x99, 0x68, 0xdb, 0x68, 0xc9, 0x1a, 0x89, 0x1a, 0x03, 0xe0, 0x99, 0x68,
0xdb, 0x68, 0xc9, 0x18, 0x89, 0x18, 0xff, 0xf7, 0x0b, 0xfc, 0x00, 0x20, 0x10, 0xbd, 0x00, 0x00,
0x54, 0x40, 0x00, 0x40, 0xfc, 0xff, 0xc0, 0xff, 0x0c, 0x42, 0x00, 0x40, 0xcf, 0xff, 0xe3, 0xff,
0x3c, 0x06, 0x00, 0x20, 0xff, 0xff, 0x03, 0x00, 0x62, 0x3d, 0x01, 0x00, 0x9e, 0xc2, 0xfe, 0xff,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xd9, 0x32, 0x00, 0x00,
0x70, 0xb5, 0x71, 0x4a, 0x03, 0x29, 0x02, 0xd1, 0x20, 0x32, 0x70, 0x48, 0x07, 0xe0, 0x01, 0x29,
0x04, 0xd1, 0xc4, 0x22, 0x52, 0x00, 0x97, 0x20, 0x80, 0x00, 0x00, 0xe0, 0x6c, 0x48, 0x00, 0x21,
0x00, 0x23, 0x6c, 0x4e, 0x9c, 0x00, 0x15, 0x59, 0x35, 0x51, 0x5b, 0x1c, 0x08, 0x2b, 0xf9, 0xdb,
0x8a, 0x00, 0x83, 0x58, 0x68, 0x4c, 0xa3, 0x50, 0x49, 0x1c, 0x05, 0x29, 0xf8, 0xdb, 0x67, 0x48,
0x01, 0x68, 0x08, 0x22, 0x0a, 0x43, 0x02, 0x60, 0x70, 0xbd, 0x70, 0xb5, 0x04, 0x00, 0xa5, 0x68,
0x00, 0xf0, 0x12, 0xf8, 0x62, 0x4e, 0x30, 0x68, 0x01, 0x21, 0x01, 0x43, 0x31, 0x60, 0x20, 0x00,
0xff, 0xf7, 0xc6, 0xff, 0xf0, 0x6b, 0x07, 0x21, 0x88, 0x43, 0xf0, 0x63, 0x28, 0x6e, 0x01, 0x0e,
0x03, 0x20, 0xfe, 0xf7, 0xc5, 0xfe, 0x70, 0xbd, 0x10, 0xb5, 0x82, 0x68, 0x58, 0x48, 0x03, 0x68,
0x0c, 0x24, 0xa3, 0x43, 0x04, 0x24, 0x1c, 0x43, 0x04, 0x60, 0x43, 0x68, 0x55, 0x4c, 0x1c, 0x40,
0x44, 0x60, 0x83, 0x6a, 0x54, 0x4c, 0x1c, 0x40, 0x83, 0x0c, 0x23, 0x43, 0x83, 0x62, 0x01, 0x29,
0x02, 0xd1, 0xa0, 0x23, 0x5b, 0x03, 0x01, 0xe0, 0x80, 0x23, 0x1b, 0x03, 0x04, 0x69, 0x64, 0x0f,
0x64, 0x07, 0x23, 0x43, 0x4d, 0x4c, 0x1c, 0x43, 0x04, 0x61, 0x12, 0x7d, 0xd2, 0x07, 0x06, 0xd4,
0x4b, 0x4a, 0x13, 0x68, 0x9b, 0x0b, 0x9b, 0x03, 0x4a, 0x4c, 0x1c, 0x43, 0x14, 0x60, 0x01, 0x29,
0x02, 0xd1, 0x80, 0x21, 0xc9, 0x05, 0x01, 0xe0, 0xc0, 0x21, 0x09, 0x06, 0x02, 0x69, 0xd2, 0x00,
0xd2, 0x08, 0x11, 0x43, 0x01, 0x61, 0x44, 0x48, 0x01, 0x68, 0x44, 0x4a, 0x0a, 0x40, 0x02, 0x60,
0x10, 0xbd, 0x00, 0x00, 0xf0, 0xb5, 0x0b, 0x00, 0x81, 0x68, 0x01, 0x2b, 0x03, 0xd0, 0x5a, 0x1e,
0x92, 0x41, 0xd2, 0x0f, 0x00, 0xe0, 0x01, 0x22, 0x3d, 0x4b, 0x58, 0x68, 0x3d, 0x4c, 0x04, 0x40,
0x8a, 0x20, 0x00, 0x04, 0x20, 0x43, 0x58, 0x60, 0x18, 0x68, 0x3e, 0x24, 0xa0, 0x43, 0x2a, 0x24,
0x04, 0x43, 0x1c, 0x60, 0x0f, 0x24, 0x00, 0xbf, 0x3b, 0xa0, 0xcd, 0x69, 0xad, 0x0c, 0x25, 0x40,
0x40, 0x19, 0x00, 0x1f, 0x05, 0x78, 0x08, 0x00, 0xec, 0x30, 0x86, 0x69, 0x32, 0x4f, 0x37, 0x40,
0xbc, 0x46, 0xaf, 0x02, 0xfc, 0x26, 0x36, 0x02, 0x3e, 0x40, 0x67, 0x46, 0x3e, 0x43, 0x86, 0x61,
0x00, 0x2a, 0x00, 0xd0, 0x06, 0x25, 0x5e, 0x68, 0xb6, 0x0b, 0xb6, 0x03, 0x00, 0x68, 0x00, 0x0b,
0xff, 0x27, 0xbf, 0x01, 0x07, 0x40, 0x3d, 0x43, 0x35, 0x43, 0x5d, 0x60, 0x00, 0x2a, 0x03, 0xd0,
0x04, 0x24, 0xa0, 0x20, 0x00, 0x04, 0x06, 0xe0, 0xc8, 0x69, 0x81, 0x0d, 0x0c, 0x40, 0x81, 0x00,
0xf0, 0x20, 0x00, 0x04, 0x08, 0x40, 0x21, 0x49, 0x0a, 0x68, 0x21, 0x4b, 0x13, 0x40, 0x1c, 0x43,
0x20, 0x43, 0x08, 0x60, 0xf0, 0xbd, 0x70, 0xb5, 0x06, 0x00, 0x08, 0x24, 0x1d, 0x4d, 0x01, 0x22,
0x31, 0x00, 0x28, 0x88, 0xff, 0xf7, 0x68, 0xfd, 0x28, 0x80, 0x2d, 0x1d, 0x00, 0x22, 0x31, 0x00,
0x28, 0x78, 0xff, 0xf7, 0x61, 0xfd, 0xff, 0x28, 0x00, 0xdd, 0xff, 0x20, 0x28, 0x70, 0x2d, 0x1d,
0x64, 0x08, 0xf3, 0xd1, 0x70, 0xbd, 0x00, 0x00, 0xb4, 0x06, 0x00, 0x20, 0xa8, 0x07, 0x00, 0x20,
0x94, 0x07, 0x00, 0x20, 0x84, 0x40, 0x00, 0x40, 0xa4, 0x40, 0x00, 0x40, 0x04, 0x20, 0x00, 0x40,
0xbc, 0x41, 0x00, 0x40, 0xff, 0xff, 0xf1, 0x7f, 0xff, 0x8f, 0xff, 0xff, 0x00, 0x7f, 0x20, 0x00,
0x84, 0x42, 0x00, 0x40, 0x28, 0x28, 0x00, 0x00, 0x74, 0x40, 0x00, 0x40, 0xff, 0x7f, 0xf8, 0xff,
0x78, 0x40, 0x00, 0x40, 0xff, 0xff, 0x05, 0xff, 0xff, 0x03, 0xff, 0xff, 0x80, 0x42, 0x00, 0x40,
0xf0, 0xff, 0x0f, 0xff, 0x58, 0x40, 0x00, 0x40, 0x24, 0x17, 0x10, 0x0c, 0x09, 0x07, 0x06, 0x05,
0x04, 0x00, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x71, 0x67, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0xd3, 0x29, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x9d, 0x64, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x07, 0x1b, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0xff, 0x29, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0xa5, 0x29, 0x00, 0x00, 0x10, 0xb5, 0x61, 0x4c, 0x00, 0x20, 0x20, 0x60, 0xa0, 0x60, 0x60, 0x49,
0x40, 0x22, 0xd2, 0x43, 0x0a, 0x60, 0x12, 0x0c, 0x4a, 0x60, 0x1f, 0x22, 0x8a, 0x60, 0xc8, 0x60,
0x88, 0x63, 0xff, 0xf7, 0xbf, 0xff, 0x40, 0x20, 0x5a, 0x49, 0x08, 0x60, 0x00, 0xe0, 0x20, 0xbf,
0xa1, 0x68, 0x00, 0x29, 0xfb, 0xd0, 0x58, 0x49, 0x08, 0x60, 0x21, 0x68, 0x31, 0x31, 0x57, 0x48,
0xff, 0xf7, 0xb8, 0xff, 0x10, 0xbd, 0x80, 0xb5, 0xff, 0xf7, 0xbc, 0xff, 0xfa, 0x20, 0x40, 0x00,
0xff, 0xf7, 0xc0, 0xff, 0xff, 0xf7, 0xd6, 0xff, 0x02, 0xbd, 0xf0, 0xb5, 0x85, 0xb0, 0x50, 0x48,
0x00, 0x68, 0xc1, 0x05, 0xc9, 0x0f, 0x70, 0xd0, 0x00, 0x20, 0x47, 0x49, 0x08, 0x70, 0x4d, 0x48,
0x00, 0x68, 0x4d, 0x49, 0x01, 0x43, 0x4b, 0x48, 0x01, 0x60, 0x08, 0x20, 0x4b, 0x4f, 0x39, 0x68,
0x01, 0x43, 0x39, 0x60, 0x4a, 0x4e, 0x31, 0x68, 0x08, 0x43, 0x30, 0x60, 0xfa, 0x20, 0xc0, 0x00,
0xff, 0xf7, 0xa0, 0xff, 0xff, 0xf7, 0x86, 0xff, 0x40, 0x24, 0x3e, 0x48, 0x04, 0x60, 0x00, 0x21,
0x13, 0x20, 0xc0, 0x43, 0xff, 0xf7, 0xcf, 0xff, 0x05, 0x00, 0x00, 0x21, 0x14, 0x20, 0xff, 0xf7,
0xca, 0xff, 0x28, 0x21, 0x40, 0x1b, 0xff, 0xf7, 0x7d, 0xff, 0x02, 0x90, 0x0f, 0x21, 0xc9, 0x43,
0x00, 0x20, 0xff, 0xf7, 0xc0, 0xff, 0x05, 0x00, 0x0f, 0x21, 0x00, 0x20, 0xff, 0xf7, 0xbb, 0xff,
0x1f, 0x21, 0x40, 0x1b, 0xff, 0xf7, 0x6e, 0xff, 0x05, 0x00, 0x00, 0x21, 0x00, 0x20, 0xff, 0xf7,
0xb2, 0xff, 0x6b, 0x46, 0x2a, 0x00, 0x02, 0x99, 0x00, 0xf0, 0x32, 0xf8, 0x01, 0x99, 0x00, 0x98,
0xff, 0xf7, 0xa9, 0xff, 0x03, 0xab, 0x2a, 0x00, 0x02, 0x99, 0x00, 0xf0, 0x29, 0xf8, 0x01, 0x98,
0x04, 0x99, 0x41, 0x18, 0x00, 0x98, 0x03, 0x9a, 0x80, 0x18, 0xff, 0xf7, 0x5b, 0xff, 0x22, 0x48,
0x04, 0x60, 0x08, 0x24, 0xe4, 0x43, 0x30, 0x68, 0x20, 0x40, 0x30, 0x60, 0xfa, 0x20, 0xc0, 0x00,
0xff, 0xf7, 0x58, 0xff, 0xff, 0xf7, 0x3e, 0xff, 0x38, 0x68, 0x04, 0x40, 0x3c, 0x60, 0x1d, 0x48,
0x00, 0x68, 0x20, 0x49, 0x01, 0x40, 0x1b, 0x48, 0x01, 0x60, 0x13, 0x48, 0x00, 0x78, 0x00, 0x28,
0x04, 0xd0, 0x00, 0x21, 0x00, 0x20, 0xff, 0xf7, 0x3d, 0xff, 0x33, 0x20, 0x05, 0xb0, 0xf0, 0xbd,
0x7c, 0xb5, 0x15, 0x00, 0x1c, 0x00, 0x18, 0x4a, 0x90, 0x42, 0x01, 0xd3, 0x11, 0x30, 0x00, 0xe0,
0x11, 0x38, 0x6b, 0x46, 0x01, 0xaa, 0x15, 0x4e, 0x30, 0x1a, 0xff, 0xf7, 0x3b, 0xff, 0x00, 0x98,
0x00, 0x28, 0x03, 0xd0, 0x2a, 0x00, 0xc1, 0x17, 0xff, 0xf7, 0x3c, 0xff, 0x01, 0x99, 0x21, 0x60,
0x60, 0x60, 0x73, 0xbd, 0x00, 0x00, 0x00, 0x00, 0x04, 0x10, 0x00, 0x20, 0x00, 0x10, 0x00, 0x20,
0x0c, 0x34, 0x00, 0x40, 0x00, 0xe1, 0x00, 0xe0, 0x80, 0xe1, 0x00, 0xe0, 0x80, 0x95, 0x0a, 0x30,
0x00, 0x40, 0x00, 0x40, 0x78, 0x42, 0x00, 0x40, 0x00, 0xa0, 0x40, 0x00, 0x04, 0x0c, 0x00, 0x40,
0x28, 0x34, 0x00, 0x40, 0xff, 0x5f, 0xbf, 0xff, 0x91, 0x65, 0x00, 0x00, 0x90, 0x65, 0x00, 0x00,
0x10, 0xb5, 0x04, 0x00, 0xff, 0xf7, 0x49, 0xff, 0x00, 0x28, 0x01, 0xd0, 0x80, 0x00, 0xe0, 0x71,
0xa0, 0x79, 0x20, 0x21, 0x01, 0x43, 0xa1, 0x71, 0x10, 0xbd, 0x70, 0x47, 0x08, 0xb4, 0x02, 0x4b,
0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x4d, 0x5f, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b,
0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xa1, 0x63, 0x00, 0x00, 0xf8, 0xb5, 0x04, 0x00,
0xa6, 0x68, 0x00, 0x25, 0xe5, 0x61, 0x14, 0x36, 0x70, 0x6f, 0x57, 0x49, 0x01, 0x40, 0x71, 0x67,
0xa0, 0x79, 0x20, 0x21, 0x01, 0x43, 0xa1, 0x71, 0x20, 0x00, 0x00, 0xf0, 0x66, 0xf8, 0x30, 0x6f,
0x41, 0x03, 0xc9, 0x0f, 0x05, 0xd0, 0x20, 0x00, 0xfe, 0xf7, 0xda, 0xfc, 0x20, 0x00, 0xfe, 0xf7,
0xbf, 0xff, 0x70, 0x20, 0x30, 0x5c, 0xc0, 0x06, 0x02, 0xd5, 0x20, 0x00, 0xff, 0xf7, 0xce, 0xff,
0x30, 0x6f, 0x40, 0x05, 0x0b, 0xd5, 0x20, 0x00, 0xff, 0xf7, 0x3f, 0xf8, 0x20, 0x00, 0xff, 0xf7,
0x8a, 0xf8, 0x20, 0x00, 0xff, 0xf7, 0x34, 0xf9, 0x04, 0x20, 0x44, 0x49, 0x08, 0x60, 0x3f, 0x27,
0x30, 0x78, 0xc0, 0x07, 0x09, 0xd5, 0x30, 0x6f, 0x00, 0x0e, 0x38, 0x40, 0x05, 0xd0, 0x40, 0x48,
0xe0, 0x61, 0x20, 0x00, 0xff, 0xf7, 0xba, 0xff, 0xe5, 0x61, 0x70, 0x20, 0x30, 0x5c, 0xc0, 0x07,
0x1b, 0xd5, 0x3c, 0x48, 0xe0, 0x61, 0x20, 0x00, 0xff, 0xf7, 0x41, 0xfc, 0x20, 0x00, 0xff, 0xf7,
0x50, 0xfc, 0x20, 0x00, 0xff, 0xf7, 0x6a, 0xfc, 0xe5, 0x61, 0x04, 0x20, 0x33, 0x49, 0x08, 0x60,
0x30, 0x78, 0xc0, 0x07, 0x09, 0xd5, 0x30, 0x6f, 0x00, 0x0e, 0x07, 0x40, 0x05, 0xd0, 0x30, 0x48,
0xe0, 0x61, 0x20, 0x00, 0xff, 0xf7, 0x9a, 0xff, 0xe5, 0x61, 0x70, 0x20, 0x30, 0x5c, 0x40, 0x06,
0x0a, 0xd5, 0x2d, 0x48, 0xe0, 0x61, 0x20, 0x00, 0xff, 0xf7, 0x32, 0xfa, 0x20, 0x00, 0xff, 0xf7,
0x45, 0xfa, 0x20, 0x00, 0xff, 0xf7, 0x3e, 0xfa, 0xe5, 0x61, 0x70, 0x6f, 0x80, 0x21, 0x89, 0x05,
0x01, 0x43, 0x71, 0x67, 0x02, 0x20, 0xa0, 0x70, 0xf1, 0xbd, 0xf0, 0xb5, 0x23, 0x48, 0x01, 0x68,
0x01, 0x22, 0x0a, 0x43, 0x02, 0x60, 0x22, 0x49, 0x4a, 0x6a, 0x22, 0x4b, 0x13, 0x40, 0x22, 0x4a,
0x1a, 0x43, 0x4a, 0x62, 0x4a, 0x68, 0x21, 0x4b, 0x13, 0x40, 0x4b, 0x60, 0x0a, 0x68, 0x20, 0x4b,
0x13, 0x40, 0x20, 0x4a, 0x1a, 0x43, 0x0a, 0x60, 0x0a, 0x6d, 0x1f, 0x4b, 0x13, 0x40, 0x1f, 0x4a,
0x1a, 0x43, 0x0a, 0x65, 0x00, 0x23, 0x1e, 0x4a, 0x13, 0x80, 0x84, 0x0c, 0x54, 0x80, 0x14, 0x80,
0x1c, 0x4c, 0x20, 0x25, 0x25, 0x60, 0x1c, 0x4e, 0x36, 0x68, 0x2e, 0x40, 0x56, 0x88, 0x03, 0xd1,
0x20, 0xbf, 0x17, 0x88, 0x37, 0x42, 0xfb, 0xd0, 0x18, 0x4e, 0x16, 0x60, 0x25, 0x60, 0x18, 0x4a,
0x0a, 0x65, 0x4b, 0x62, 0x01, 0x22, 0xd2, 0x43, 0x0b, 0x68, 0x13, 0x40, 0x0b, 0x60, 0x01, 0x68,
0x0a, 0x40, 0x02, 0x60, 0xf0, 0xbd, 0x00, 0x00, 0xff, 0xff, 0xff, 0xdf, 0x00, 0xe1, 0x00, 0xe0,
0xb3, 0x2c, 0x00, 0x00, 0x19, 0x21, 0x00, 0x20, 0x01, 0x1d, 0x00, 0x20, 0x88, 0x42, 0x00, 0x40,
0xbc, 0x40, 0x00, 0x40, 0xc0, 0xff, 0xf3, 0xff, 0x25, 0x00, 0x04, 0x00, 0xff, 0xff, 0x00, 0xff,
0xfe, 0xff, 0x00, 0x00, 0x01, 0x00, 0xb8, 0x0b, 0x00, 0x80, 0x81, 0x70, 0x03, 0x6b, 0x02, 0x80,
0x60, 0x41, 0x00, 0x40, 0x80, 0xe2, 0x00, 0xe0, 0x00, 0xe2, 0x00, 0xe0, 0xff, 0xff, 0x00, 0x00,
0x10, 0x00, 0x01, 0x80, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x01, 0x24, 0x00, 0x00, 0x10, 0xb5, 0x72, 0xb6, 0x1a, 0x4c, 0xc2, 0x22, 0x52, 0x00, 0x1a, 0x49,
0x20, 0x00, 0xff, 0xf7, 0xef, 0xff, 0x60, 0x0f, 0xc0, 0x03, 0x61, 0x04, 0x49, 0x0c, 0x01, 0x43,
0x16, 0x48, 0x01, 0x80, 0x21, 0x00, 0x64, 0x31, 0x15, 0x48, 0x08, 0x60, 0x15, 0x48, 0x48, 0x60,
0x15, 0x48, 0x88, 0x60, 0x00, 0x20, 0xc8, 0x60, 0x14, 0x4a, 0x0a, 0x61, 0x48, 0x61, 0x08, 0x63,
0x13, 0x4a, 0x4a, 0x63, 0x88, 0x63, 0x86, 0x21, 0x49, 0x00, 0x61, 0x18, 0x11, 0x4a, 0x0a, 0x60,
0x11, 0x4a, 0x4a, 0x60, 0x11, 0x4a, 0x8a, 0x60, 0x11, 0x4a, 0x4a, 0x62, 0x11, 0x4a, 0x8a, 0x62,
0x11, 0x4a, 0xca, 0x62, 0x08, 0x63, 0x11, 0x48, 0x48, 0x63, 0x11, 0x48, 0x88, 0x63, 0x62, 0xb6,
0x10, 0xbd, 0x00, 0xbf, 0x60, 0x01, 0x00, 0x20, 0x1c, 0x7a, 0x00, 0x00, 0xd0, 0x00, 0x00, 0x20,
0xdd, 0x1c, 0x00, 0x20, 0x09, 0x1d, 0x00, 0x20, 0x01, 0x1d, 0x00, 0x20, 0xa9, 0x27, 0x00, 0x20,
0x6d, 0x27, 0x00, 0x20, 0x77, 0x18, 0x00, 0x20, 0x13, 0x19, 0x00, 0x20, 0x6d, 0x1a, 0x00, 0x20,
0xbb, 0x20, 0x00, 0x20, 0xdf, 0x20, 0x00, 0x20, 0x19, 0x21, 0x00, 0x20, 0x8d, 0x11, 0x00, 0x20,
0x5d, 0x17, 0x00, 0x20, 0x10, 0xb5, 0x72, 0xb6, 0x14, 0x49, 0x0a, 0x00, 0x64, 0x32, 0x00, 0x23,
0x13, 0x60, 0x53, 0x60, 0x93, 0x60, 0xd3, 0x60, 0x11, 0x4c, 0x14, 0x61, 0x53, 0x61, 0x13, 0x63,
0x10, 0x4c, 0x54, 0x63, 0x93, 0x63, 0x86, 0x22, 0x52, 0x00, 0x89, 0x18, 0x0b, 0x63, 0x4b, 0x63,
0x8b, 0x63, 0x0d, 0x4a, 0x0a, 0x60, 0x0d, 0x4a, 0x4a, 0x60, 0x0d, 0x4a, 0x8a, 0x60, 0x0d, 0x4a,
0x4a, 0x62, 0x0d, 0x4a, 0x8a, 0x62, 0x0d, 0x4a, 0xca, 0x62, 0x81, 0x79, 0x20, 0x22, 0x0a, 0x43,
0x82, 0x71, 0x02, 0x21, 0x81, 0x70, 0x62, 0xb6, 0x10, 0xbd, 0x00, 0xbf, 0x60, 0x01, 0x00, 0x20,
0x8d, 0x7e, 0x00, 0x00, 0x71, 0x66, 0x00, 0x00, 0x31, 0x7f, 0x00, 0x00, 0x33, 0x7f, 0x00, 0x00,
0x35, 0x7f, 0x00, 0x00, 0xbf, 0x34, 0x00, 0x00, 0xc1, 0x34, 0x00, 0x00, 0xc3, 0x34, 0x00, 0x00,

};

static const uint8_t ADF7030_1__PATCH_CALIBRATIONS_BLOCK_1[] = { // 0x20002fa0 - 84
0x4f, 0x66, 0x66, 0x4c, 0x69, 0x6e, 0x65, 0x43, 0x61, 0x6c, 0x69, 0x62, 0x72, 0x61, 0x74, 0x69,
0x6f, 0x6e, 0x73, 0x20, 0x56, 0x32, 0x2e, 0x31, 0x2e, 0x30, 0x30, 0x58, 0x20, 0x5e, 0x2f, 0x62,
0x72, 0x61, 0x6e, 0x63, 0x68, 0x65, 0x73, 0x2f, 0x61, 0x64, 0x66, 0x37, 0x30, 0x33, 0x30, 0x5f,
0x30, 0x78, 0x30, 0x36, 0x30, 0x32, 0x5f, 0x50, 0x33, 0x5f, 0x32, 0x5f, 0x52, 0x4f, 0x4d, 0x5f,
0x70, 0x61, 0x74, 0x63, 0x68, 0x00, 0x5e, 0x21, 0x37, 0x30, 0x33, 0x78, 0x44, 0x41, 0x02, 0x06,
0x00, 0x02, 0xa2, 0x25 
};

__root static PATCH_DESCRIPTOR_Type PATCH_CALIBRATIONS = { 
	.Name = {"CALIBRATIONS\0"}, 
	.Size = 6596,
	.nbBlock = 2,
	.pInfo = (version_info_t *)&ADF7030_1__PATCH_CALIBRATIONS_BLOCK_1[0],
	.InfoAddr = 0x20002fa0,
	.InjectSeq = 0x2971,
	.EjectSeq = 0x2a21,
	{
		{.Size = 6512, .Addr = 0x2000112c, .pData = ADF7030_1__PATCH_CALIBRATIONS_BLOCK_0 },
		{.Size = 84, .Addr = 0x20002fa0, .pData = ADF7030_1__PATCH_CALIBRATIONS_BLOCK_1 },
	}
};

#endif //__PATCH_CALIBRATIONS_HEADER__

