
/*!
 *****************************************************************************
 * @file    LCPSM.h
 * @brief   Firmware header file containing binaries of LCPSM patch
 * @version $REVISION: $
 * @date    $DATE: $
 *----------------------------------------------------------------------------
 *
Copyright (c) 2010-2016 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:
- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer.
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.
- Modified versions of the software must be conspicuously marked as such.
- This software is licensed solely and exclusively for use with processors
  manufactured by or for Analog Devices, Inc.
- This software may not be combined or merged with other code in any manner
  that would cause the software to become subject to terms and conditions
  which differ from those listed here.
- Neither the name of Analog Devices, Inc. nor the names of its
  contributors may be used to endorse or promote products derived
  from this software without specific prior written permission.
- The use of this software may or may not infringe the patent rights of one
  or more patent holders.  This license does not release you from the
  requirement that you obtain separate licenses from these patent holders
  to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON- 
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

*****************************************************************************/ 

/**
 * @brief		This LCPSM patch is an add-on feature of the adf7030-1
 *				aimed at lowering the average current during packet reception.
 * 
 * @details		It dither analog and digital section of the transceiver
 *				between "ON" and "Quasi OFF" state.
 *				This file is for ADI Internal development only. 
 * 
 * HOST SEQUENCES:
 * --------------- 
 * 	* Enabling LCPSM for the first time
 * 		1. Radio PHY must be in PHY_OFF or PHY_ON
 *  		+. Transfert the LCPSM F/W
 *  		+. Write (0x20000000 + <InjectSeq>) at location 0x20000130
 * 		+. Configure LCPSM (generic packet configuration)
 *  		+. Issue Phy RX
 * 		
 * 	* Disabling LCPSM
 * 		1. Write (0x20000000 + <EjectSeq>) at location 0x20000130
 * 		
 * 	* Re-enabling LCPSM
 * 		1. Write (0x20000000 + <InjectSeq>) at location 0x20000130
 *  
 * 	@note	___The LCPSM f/w reside within the BBRAM, user must ensure the retain bit is set___
 * 	@note	___for the LCPSM patch to be retained between sleep episodes___
 * 		
 *
 * HOWTO: (ADI Radio drivers)
 * ------
 * 	
 * 	- Download patch to PHY Radio:
 * 	 
 * 		adf7030_1__WritePatch(hSPIDevice, &PATCH_LCPSM);
 *  
 * 	- Enable the patch:
 * 	          
 * 		adf7030_1__InjectPatch(hSPIDevice, &PATCH_LCPSM);
 *  		
 * 	- Disable the patch:
 * 	 
 * 		adf7030_1__EjectPatch(hSPIDevice, &PATCH_LCPSM);
 *  		
 * 	- Verify patch integrity on the PHY:
 * 	 	
 * 		adf7030_1__VerifyPatch(hSPIDevice, &PATCH_LCPSM);
 *
 */ 


#ifndef __PATCH_LCPSM_HEADER__
#define __PATCH_LCPSM_HEADER__

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_0[] = { // 0x20000000 - 164
0x08, 0xb0, 0x00, 0x20, 0xfe, 0xbd, 0x70, 0x47, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0xb3, 0x2c, 0x00, 0x00, 0xf0, 0xb5, 0x83, 0xb0, 0x72, 0xb6, 0x0d, 0x4c,
0x27, 0x68, 0x61, 0x68, 0x01, 0x91, 0x0c, 0x4d, 0x2e, 0x68, 0x69, 0x68, 0x00, 0x91, 0x0b, 0x49,
0x21, 0x60, 0x0b, 0x49, 0x61, 0x60, 0x0b, 0x49, 0x29, 0x60, 0x0b, 0x49, 0x69, 0x60, 0xff, 0xf7,
0xe3, 0xff, 0x27, 0x60, 0x01, 0x98, 0x60, 0x60, 0x2e, 0x60, 0x00, 0x98, 0x68, 0x60, 0x62, 0xb6,
0xf7, 0xbd, 0x00, 0xbf, 0x18, 0x3e, 0x00, 0x40, 0xc8, 0x00, 0x00, 0x20, 0xf9, 0x31, 0x00, 0x00,
0x25, 0x2d, 0x00, 0x00, 0x00, 0xbf, 0x41, 0x68, 0xa9, 0x66, 0x02, 0xe0, 0x10, 0xb5, 0x0a, 0x4a,
0x13, 0x68, 0x80, 0x24, 0xa4, 0x03, 0x1c, 0x43, 0x14, 0x60, 0x08, 0x4a, 0x01, 0x23, 0x01, 0x24,
0x04, 0x43, 0xd4, 0x60, 0x00, 0x1d, 0x18, 0x43, 0x10, 0x61, 0x0b, 0x43, 0x04, 0x48, 0x03, 0x60,
0x00, 0x1f, 0x10, 0x60, 0x10, 0xbd, 0x00, 0xbf, 0x78, 0x42, 0x00, 0x40, 0x04, 0x3e, 0x00, 0x40,
0xc4, 0x00, 0x00, 0x20 
};

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_1[] = { // 0x200000c0 - 4
0x00, 0x4b, 0x18, 0x47 
};

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_2[] = { // 0x200003ec - 164
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x11, 0x6f, 0x00, 0x00,
0x38, 0xb5, 0x04, 0x00, 0x17, 0x4d, 0x28, 0x68, 0x17, 0x49, 0x01, 0x40, 0x29, 0x60, 0x20, 0x00,
0xff, 0xf7, 0xee, 0xff, 0xe0, 0x79, 0x00, 0x28, 0x22, 0xd1, 0x28, 0x68, 0x80, 0x21, 0x49, 0x04,
0x01, 0x43, 0x29, 0x60, 0xe0, 0x68, 0x41, 0x6e, 0x80, 0x22, 0x12, 0x06, 0x0a, 0x43, 0x42, 0x66,
0xc0, 0x6e, 0x0e, 0x49, 0x08, 0x60, 0x40, 0x1e, 0x80, 0x41, 0xc0, 0x0f, 0x0c, 0x49, 0x08, 0x60,
0x72, 0xb6, 0x0c, 0x49, 0x0c, 0x48, 0xff, 0xf7, 0x13, 0xfe, 0x0c, 0x48, 0x0c, 0x49, 0x01, 0x60,
0x0c, 0x49, 0x0d, 0x4a, 0x0a, 0x60, 0x0d, 0x4a, 0x42, 0x60, 0x0d, 0x48, 0x48, 0x60, 0x62, 0xb6,
0x31, 0xbd, 0x00, 0xbf, 0x78, 0x40, 0x00, 0x40, 0xff, 0xff, 0xff, 0xfe, 0xf8, 0x0f, 0x00, 0x20,
0xf4, 0x0f, 0x00, 0x20, 0xe1, 0x0e, 0x00, 0x20, 0xc5, 0x34, 0x00, 0x00, 0x18, 0x3e, 0x00, 0x40,
0x21, 0x3d, 0x00, 0x00, 0xc8, 0x00, 0x00, 0x20, 0xf5, 0xe7, 0xc0, 0x46, 0x0d, 0x39, 0x00, 0x00,
0x02, 0x90, 0x05, 0xe0 
};

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_3[] = { // 0x20000564 - 140
0x72, 0xb6, 0x0b, 0x49, 0x0b, 0x4a, 0x91, 0x62, 0xc0, 0x68, 0x00, 0x28, 0x03, 0xd0, 0x41, 0x6e,
0x49, 0x00, 0x49, 0x08, 0x41, 0x66, 0x08, 0x48, 0x00, 0x21, 0x01, 0x60, 0x41, 0x60, 0x81, 0x60,
0xc1, 0x60, 0x06, 0x48, 0x01, 0x68, 0x06, 0x4a, 0x0a, 0x40, 0x02, 0x60, 0x62, 0xb6, 0x70, 0x47,
0x11, 0x6f, 0x00, 0x00, 0x60, 0x01, 0x00, 0x20, 0x10, 0x3e, 0x00, 0x40, 0x78, 0x40, 0x00, 0x40,
0xff, 0xff, 0xff, 0xfe, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46,
0x01, 0x24, 0x00, 0x00, 0x10, 0xb5, 0x72, 0xb6, 0x08, 0x4c, 0xc2, 0x22, 0x52, 0x00, 0x08, 0x49,
0x20, 0x00, 0xff, 0xf7, 0xef, 0xff, 0x60, 0x0f, 0xc0, 0x03, 0x61, 0x04, 0x49, 0x0c, 0x01, 0x43,
0x04, 0x48, 0x01, 0x80, 0x04, 0x48, 0xa0, 0x62, 0x62, 0xb6, 0x10, 0xbd, 0x60, 0x01, 0x00, 0x20,
0x1c, 0x7a, 0x00, 0x00, 0xd0, 0x00, 0x00, 0x20, 0xfd, 0x03, 0x00, 0x20 
};

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_4[] = { // 0x20000bf8 - 1016
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x81, 0x2d, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xe5, 0x2f, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xdd, 0x1b, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xd9, 0x32, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0xe3, 0x1a, 0x00, 0x00,
0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc, 0x60, 0x47, 0xc0, 0x46, 0x29, 0x32, 0x00, 0x00,
0xf1, 0xb5, 0x82, 0xb0, 0x80, 0x68, 0x00, 0x90, 0x02, 0x98, 0xff, 0xf7, 0xc9, 0xff, 0x02, 0x98,
0xff, 0xf7, 0xce, 0xff, 0x07, 0x25, 0x00, 0x98, 0x40, 0x69, 0xc0, 0x0e, 0x28, 0x40, 0x82, 0x4e,
0x01, 0x24, 0x07, 0x21, 0xc9, 0x43, 0x01, 0x28, 0x03, 0xd1, 0xf0, 0x6b, 0x01, 0x40, 0x21, 0x43,
0x03, 0xe0, 0x00, 0x28, 0x02, 0xd1, 0xf0, 0x6b, 0x01, 0x40, 0xf1, 0x63, 0x00, 0x98, 0x40, 0x6a,
0x01, 0x0e, 0x21, 0x40, 0x22, 0xd0, 0x00, 0x0f, 0xff, 0xf7, 0xba, 0xff, 0x00, 0x98, 0x40, 0x6a,
0x40, 0x0e, 0x05, 0x40, 0x01, 0x20, 0xa8, 0x40, 0x74, 0x49, 0x8a, 0x6b, 0x82, 0x43, 0x8a, 0x63,
0x2a, 0x00, 0x18, 0x32, 0xff, 0x23, 0x04, 0x2d, 0x07, 0xd2, 0xed, 0x00, 0x0f, 0x68, 0xab, 0x40,
0x9f, 0x43, 0xaa, 0x40, 0x3a, 0x43, 0x0a, 0x60, 0x07, 0xe0, 0x2d, 0x1f, 0xed, 0x00, 0x4f, 0x68,
0xab, 0x40, 0x9f, 0x43, 0xaa, 0x40, 0x3a, 0x43, 0x4a, 0x60, 0xc8, 0x61, 0x68, 0x4d, 0x03, 0x27,
0xa8, 0x6b, 0x38, 0x43, 0xa8, 0x63, 0x28, 0x6a, 0x08, 0x21, 0x88, 0x43, 0x28, 0x62, 0xa8, 0x68,
0x64, 0x49, 0x01, 0x40, 0x64, 0x48, 0x08, 0x43, 0xa8, 0x60, 0x28, 0x69, 0x63, 0x49, 0x01, 0x43,
0x29, 0x61, 0xe8, 0x68, 0x79, 0x04, 0x01, 0x43, 0xe9, 0x60, 0x28, 0x68, 0x61, 0x06, 0x01, 0x43,
0x29, 0x60, 0xe8, 0x69, 0x20, 0x43, 0xe8, 0x61, 0x68, 0x68, 0x21, 0x03, 0x01, 0x43, 0x69, 0x60,
0x28, 0x6a, 0x10, 0x21, 0x01, 0x43, 0x29, 0x62, 0x28, 0x6a, 0x40, 0x21, 0x01, 0x43, 0x29, 0x62,
0x00, 0x98, 0x00, 0x6b, 0x56, 0x49, 0x0a, 0x68, 0x56, 0x4b, 0x13, 0x40, 0x9c, 0x46, 0x02, 0x02,
0xcb, 0x0b, 0x1a, 0x40, 0x63, 0x46, 0x1a, 0x43, 0x00, 0x0a, 0x63, 0x05, 0x18, 0x40, 0x10, 0x43,
0x82, 0x22, 0x52, 0x03, 0x02, 0x43, 0x0a, 0x60, 0x68, 0x69, 0x89, 0x0b, 0x01, 0x43, 0x69, 0x61,
0x68, 0x6e, 0x4d, 0x49, 0x01, 0x40, 0x58, 0x09, 0x08, 0x43, 0x68, 0x66, 0x28, 0x6e, 0x80, 0x21,
0x09, 0x06, 0x01, 0x43, 0x29, 0x66, 0x00, 0x98, 0x40, 0x69, 0x20, 0x40, 0x28, 0x6e, 0x04, 0xd0,
0xe0, 0x21, 0xc9, 0x05, 0x01, 0x43, 0x29, 0x66, 0x04, 0xe0, 0x44, 0x49, 0x01, 0x40, 0x78, 0x07,
0x08, 0x43, 0x28, 0x66, 0x30, 0x68, 0x20, 0x43, 0x30, 0x60, 0x30, 0x68, 0x0c, 0x21, 0x88, 0x43,
0x30, 0x60, 0x02, 0x98, 0xff, 0xf7, 0x3c, 0xff, 0xa8, 0x6d, 0xb8, 0x43, 0x20, 0x43, 0xa8, 0x65,
0x28, 0x6a, 0x08, 0x21, 0x01, 0x43, 0x29, 0x62, 0x28, 0x69, 0x39, 0x49, 0x01, 0x40, 0x29, 0x61,
0xe8, 0x68, 0x38, 0x49, 0x01, 0x40, 0xe9, 0x60, 0x00, 0x98, 0x00, 0x6b, 0xaa, 0x68, 0x36, 0x49,
0x11, 0x40, 0x43, 0x09, 0x3a, 0x02, 0x1a, 0x40, 0x0a, 0x43, 0x80, 0x00, 0xf8, 0x21, 0xc9, 0x01,
0x01, 0x40, 0x11, 0x43, 0xa9, 0x60, 0xa8, 0x6b, 0x07, 0x43, 0xaf, 0x63, 0x08, 0x21, 0x03, 0x20,
0xff, 0xf7, 0x1e, 0xff, 0xe8, 0x6b, 0x1f, 0x21, 0x01, 0x43, 0xe9, 0x63, 0x19, 0x21, 0x03, 0x20,
0xff, 0xf7, 0x16, 0xff, 0x00, 0x98, 0x40, 0x69, 0x20, 0x40, 0x08, 0xd0, 0x68, 0x6d, 0x0f, 0x21,
0x01, 0x43, 0x69, 0x65, 0x30, 0x6d, 0x30, 0x21, 0x01, 0x43, 0x31, 0x65, 0x02, 0xe0, 0x02, 0x98,
0xff, 0xf7, 0x0e, 0xff, 0x28, 0x6e, 0xa1, 0x06, 0x01, 0x43, 0x29, 0x66, 0x68, 0x6e, 0x61, 0x04,
0x01, 0x43, 0x69, 0x66, 0x28, 0x6e, 0x40, 0x00, 0x40, 0x08, 0x28, 0x66, 0x1b, 0x48, 0x01, 0x68,
0x08, 0x22, 0x0a, 0x43, 0x02, 0x60, 0x00, 0x98, 0xc1, 0x6a, 0x19, 0x48, 0x42, 0x68, 0x19, 0x4b,
0x13, 0x40, 0xca, 0x00, 0xf8, 0x25, 0xad, 0x00, 0x15, 0x40, 0x1d, 0x43, 0x49, 0x0b, 0x06, 0x22,
0x0a, 0x40, 0x2a, 0x43, 0x42, 0x60, 0x01, 0x68, 0x82, 0x0d, 0x0a, 0x43, 0x02, 0x60, 0x41, 0x68,
0x0c, 0x43, 0x44, 0x60, 0xf7, 0xbd, 0x00, 0xbf, 0xbc, 0x41, 0x00, 0x40, 0x00, 0x08, 0x00, 0x40,
0x18, 0x40, 0x00, 0x40, 0xcf, 0x00, 0xff, 0xff, 0x30, 0x80, 0x00, 0x00, 0x80, 0xc1, 0x41, 0x00,
0x88, 0x42, 0x00, 0x40, 0xff, 0x3f, 0xcf, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0x8f,
0x7f, 0x3e, 0xfe, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xcf, 0x80, 0xff, 0xff, 0x04, 0x20, 0x00, 0x40,
0xb8, 0x40, 0x00, 0x40, 0x19, 0xfc, 0xff, 0xff, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0x23, 0x38, 0x00, 0x00, 0x08, 0xb4, 0x02, 0x4b, 0x9c, 0x46, 0x08, 0xbc,
0x60, 0x47, 0xc0, 0x46, 0x4d, 0x38, 0x00, 0x00, 0xf3, 0xb5, 0x81, 0xb0, 0xc5, 0x68, 0x20, 0x27,
0x3c, 0x4c, 0x01, 0xe0, 0x3c, 0x49, 0x48, 0x60, 0x3b, 0x48, 0x40, 0x68, 0x3a, 0x49, 0x09, 0x68,
0x01, 0x43, 0x0d, 0xd1, 0x28, 0x6d, 0xff, 0x21, 0x88, 0x43, 0x05, 0x21, 0x01, 0x43, 0x29, 0x65,
0x36, 0x48, 0x20, 0x60, 0x90, 0x20, 0x40, 0x00, 0x35, 0x49, 0x08, 0x60, 0xff, 0xf7, 0x74, 0xf8,
0x28, 0x6d, 0x01, 0x06, 0x15, 0xd0, 0xff, 0x21, 0x88, 0x43, 0x28, 0x65, 0x2e, 0x48, 0x40, 0x68,
0x01, 0x28, 0x03, 0xd1, 0x2c, 0x48, 0x00, 0x68, 0x00, 0x28, 0xdb, 0xd0, 0x02, 0x99, 0x01, 0x98,
0xff, 0xf7, 0x6e, 0xf8, 0x28, 0x6e, 0x00, 0x0c, 0x00, 0x21, 0x21, 0x80, 0xe1, 0x0c, 0x61, 0x80,
0x3b, 0xe0, 0x28, 0x6e, 0x86, 0xb2, 0x00, 0x20, 0x20, 0x80, 0xe0, 0x0c, 0x60, 0x80, 0x12, 0xe0,
0x24, 0x48, 0x00, 0x68, 0x38, 0x40, 0x61, 0x88, 0x03, 0xd1, 0x20, 0xbf, 0x20, 0x88, 0x08, 0x42,
0xfb, 0xd0, 0xe0, 0x0c, 0x20, 0x80, 0x1e, 0x48, 0x07, 0x60, 0x04, 0x2e, 0x03, 0xd2, 0x02, 0x98,
0xc0, 0x6c, 0xff, 0xf7, 0xa1, 0xff, 0x30, 0x00, 0x46, 0x1e, 0x00, 0x28, 0xe8, 0xd1, 0x68, 0x6e,
0x40, 0x01, 0x40, 0x09, 0x82, 0xb2, 0x41, 0x01, 0x49, 0x15, 0x02, 0x98, 0xc0, 0x6c, 0xff, 0xf7,
0x9b, 0xff, 0x00, 0x28, 0xc2, 0xd0, 0x28, 0x6d, 0xff, 0x21, 0x88, 0x43, 0x28, 0x65, 0xf7, 0xbd,
0x10, 0x49, 0x09, 0x68, 0x39, 0x40, 0x62, 0x88, 0x03, 0xd1, 0x20, 0xbf, 0x21, 0x88, 0x11, 0x42,
0xfb, 0xd0, 0xe1, 0x0c, 0x21, 0x80, 0x0a, 0x49, 0x0f, 0x60, 0x01, 0x00, 0x48, 0x1e, 0x00, 0x29,
0xee, 0xd1, 0x02, 0x99, 0x01, 0x98, 0xff, 0xf7, 0x43, 0xfe, 0x03, 0x48, 0x40, 0x68, 0x40, 0x1e,
0x88, 0xe7, 0x00, 0xbf, 0x60, 0x41, 0x00, 0x40, 0xf4, 0x0f, 0x00, 0x20, 0xff, 0xff, 0x00, 0x00,
0x80, 0xe2, 0x00, 0xe0, 0x00, 0xe2, 0x00, 0xe0 
};

static const uint8_t ADF7030_1__PATCH_LCPSM_BLOCK_5[] = { // 0x20002fa0 - 84
0x4c, 0x43, 0x50, 0x53, 0x4d, 0x20, 0x56, 0x31, 0x2e, 0x30, 0x2e, 0x30, 0x32, 0x58, 0x20, 0x5e,
0x2f, 0x62, 0x72, 0x61, 0x6e, 0x63, 0x68, 0x65, 0x73, 0x2f, 0x61, 0x64, 0x66, 0x37, 0x30, 0x33,
0x30, 0x5f, 0x30, 0x78, 0x30, 0x36, 0x30, 0x32, 0x5f, 0x50, 0x33, 0x5f, 0x32, 0x5f, 0x52, 0x4f,
0x4d, 0x5f, 0x70, 0x61, 0x74, 0x63, 0x68, 0x5f, 0x6c, 0x63, 0x70, 0x73, 0x6d, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5e, 0x21, 0x37, 0x30, 0x33, 0x78, 0x44, 0x41, 0x02, 0x06,
0x00, 0x02, 0x94, 0x25 
};

__root static PATCH_DESCRIPTOR_Type PATCH_LCPSM = { 
	.Name = {"LCPSM\0"}, 
	.Size = 1572,
	.nbBlock = 6,
	.pInfo = (version_info_t *)&ADF7030_1__PATCH_LCPSM_BLOCK_5[0],
	.InfoAddr = 0x20002fa0,
	.InjectSeq = 0x05b9,
	.EjectSeq = 0x0565,
	{
		{.Size = 164, .Addr = 0x20000000, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_0 },
		{.Size = 4, .Addr = 0x200000c0, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_1 },
		{.Size = 164, .Addr = 0x200003ec, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_2 },
		{.Size = 140, .Addr = 0x20000564, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_3 },
		{.Size = 1016, .Addr = 0x20000bf8, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_4 },
		{.Size = 84, .Addr = 0x20002fa0, .pData = ADF7030_1__PATCH_LCPSM_BLOCK_5 },
	}
};

#endif //__PATCH_LCPSM_HEADER__

