/*!
 *****************************************************************************
 * @file:    mainpage_adf7030_1.h
 * @brief:   CMSIS Cortex-M3 Main Documentation Page for
 *           ADI ADF7030-1 Device Driver Series
 * @version: $Revision: xxxx $
 * @date:    $Date: 2016-06-29 12:30:12 (Wed, 29 Jun 2016) $
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2010-2016 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors
    manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
    that would cause the software to become subject to terms and conditions
    which differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one
    or more patent holders.  This license does not release you from the
    requirement that you obtain separate licenses from these patent holders
    to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/* "Mainpage" is the main page for the DoxyGen output.
   Use it to present overview of the chip, drivers, release notes, etc.
   Use the "\section" directive to create section headers.
   Use the "\htmlinclude" directive to import html documentation.
 */

/*! \mainpage ADF7030-1 Device Driver API Overview (Compatible with ADuCM302x_EZ-KIT_Lite BSP rev1.0.1)
   \n
   \section ChipIntro ADF7030-1 Introduction
   \n
   \n The ADF7030-1 is a fully integrated, radio transceiver achieving high performance at very low power.
   \n The ADF7030-1 is ideally suited for applications that require long range, network robustness, and long battery life.
   \n It is suitable for applications that operate in the ISM, SRD, and licensed frequency bands
   \n at 169 MHz, 426 MHz to 470 MHz, and 862 MHz to 960 MHz. It provides extensive support for standards-based protocols
   \n like IEEE802.15.4g while also providing flexibility to support a wide range of proprietary protocols.
   \n 
   \n The highly configurable low intermediate frequency (IF) receiver supports a large range of IF bandwidths from 3.6 kHz to 487 kHz.
   \n This allows the ADF7030-1 to support ultranarrow-band, narrow-band, and wideband channel spacing.
   \n 
   \n The ADF7030-1 features two independent PAs supporting output power ranges of −20 dBm to +13 dBm and −20 dBm to +17 dBm.
   \n The PAs support ultrafine adjustment of the power with a step resolution of 0.1 dB. The PA output power is exceptionally
   \n robust over temperature and voltage. The PAs have an automatic power ramp control to prevent spectral splatter and help meet regulatory standards.
   \n 
   \n The ADF7030-1 features an on-chip ARM® Cortex®-M0 processor that performs radio control, radio calibration, and packet management.
   \n Cortex-M0 eases the processing burden of the host processor because the ADF7030-1 integrates the lower layers of a typical
   \n communication protocol stack. This internal processor also permits the download and execution of Analog Devices, Inc.,
   \n provided firmware modules that can extend the functionality of the ADF7030-1.
   \n 
   \n The ADF7030-1 has two packet modes: generic packet mode and IEEE802.15.4g mode. In generic packet mode, 
   \n the packet format is highly flexible and fully programmable, thereby ensuring its compatibility with proprietary packet formats.
   \n In IEEE802.15.4g packet mode, the packet format conforms to the IEEE802.15.4g standard. FEC, as per the IEEE802.15.4g standard, is also supported.
   \n 
   \n The ADF7030-1 operates with a power supply range of 2.2 V to 3.6 V and has very low power consumption in both Tx and Rx modes,
   \n enabling long lifetimes in battery-operated systems. An ultralow power deep sleep mode achieves a typical current of 10 nA with
   \n the configuration memory retained.
   \n 
   \n The ADF7030-1 supports smart wake mode (SWM) where the ADF7030-1 can wake up autonomously from sleep using an internal RTC
   \n without intervention from the host processor. After wake-up, the ADF7030-1 operates autonomously. This functionality allows
   \n carrier sense, packet sniffing, and packet reception while the host processor is in sleep, thereby reducing overall system current consumption.
   \n The ADF7030-1 autonomous operation can also be triggered by the Host processor using the interrupt input of the ADF7030-1.
   \n 
   \n A complete wireless solution can be built using a small number of external discrete components and a host processor (typically a microcontroller).
   \n The host processor can configure the ADF7030-1 using a simple command-based protocol over a standard 4-wire SPI interface.
   \n A single-byte command transitions the radio between states or performs a radio function.
   \n 
   \n The ADF7030-1 is available in two package types: a 6 mm × 6 mm 40-lead LFCSP and a 7 mm × 7 mm 48-lead LQFP.
   \n Both package types use NiPdAu plating to mitigate against silver migration in high humidity applications.
   \n The ADF7030-1 operating temperature range is −40°C to +85°C.
   \n 
   \n Applications
   \n 	- IEEE 802.15.4g (MR-FSK PHY)
   \n 	- Wireless M-Bus (EN 13757-4)
   \n 	- Smart metering
   \n 	- Security and building automation
   \n 	- Active tag asset tracking
   \n 	- Industrial control
   \n 	- Wireless sensor networks (WSNs)
   \n
   \n
   \section DriverIntro API Reference Manual
   \n This "ADF7030-1 Device Drivers API Reference Manual" documents a high-level language C
   \n Programming environment providing an Application Programming Interface (API)
   \n supporting a quick and easy functional interface to the ADF7030-1 low power transceiver peripherals.
   \n
   \n Detailed knowledge of the various controller internals (control registers,
   \n register mapping, bitmaps, etc.) is not required to make effective use of the
   \n peripherals; simply open the device driver and use it.  Basic familiarity with
   \n the Cortex M3 architecture, relevant communications protocols and the third-party
   \n development tools is assumed.
   \n
   \n Various example are included to demonstrate use of the Device Driver programming model.
   \n
   \n
   \section SettingStarted Getting Started Guide
   \n Please visit http://www.analog.com/en/design-center/evaluation-hardware-and-software/evaluation-boards-kits/EVAL-ADF7030-1EZ-KIT.html
   \n for information on the EVAL-ADF7030-1EZ-KIT and how to use it.
   \n
   \n
   \section ReleaseNotes Release Notes
   \n This driver is currently under development. This release is an alpha version. ADI reserve the right to add and remove
   \n functionality to this version of the driver.
   \n Future revision of the driver will add support for PHY IRQ and and full support of Radio Command interface
   \n 
   \section ReleaseDependencies Release Dependencies
   \n Requires "ADuCM302x Board Support Package"
   \n 	- http://download.analog.com/tools/EZBoards/CM302x/Releases/Release_1.0.1/ADuCM302x_Software-Rel1.0.1.exe
   \n
   \n Requires IAR embedded workbench version 7.40.1 or later
   \n
   \n
   \section Datasheet  ADF7030-1 Datasheet
   \n Please read "ADF7030-1 Datasheet" for general information on the ADF7030-1 integrated radio transceiver.
   \n	- http://www.analog.com/media/en/technical-documentation/data-sheets/ADF7030-1.pdf
   \n
   \n
   \section UserGuideHW  Hardware User Guide
   \n Please read the "ADF7030-1 Software Reference Manual" for general information the the  
   \n software interface to the adf7030-1. The Document can be downloaded at the following location
   \n 	- https://www.analog.com/adf7030-1-hardware-reference-manual?doc=adf7030-1.pdf (UG-1002)
   \n
   \n
   \section UserGuideFW  Firmware User Guide
   \n Please read the "ADF7030-1 Hardware Reference Manual" for general information the the  
   \n hardware of the adf7030-1. The Document can be downloaded at the following location
   \n 	- https://www.analog.com/adf7030-1-software-reference-manual?doc=adf7030-1.pdf (UG-957)
   \n
   \n
   \section Support Technical or Customer Support
   \n You can reach Analog Devices, Inc. Customer Support at:

        -    Web access at
                 - http://www.analog.com/support

        -    For IAR tool chain support please visit
                 -http://www.iar.com/support 

        -    E-mail processor questions to
                 - processor.support@analog.com
                 - processor.china@analog.com (China and Taiwan only)

        -    Phone questions to 1-800-ANALOGD

        -    Contact your Analog Devices, Inc. local sales office or authorized distributor

        -    Send questions by mail to:
   \code
   Analog Devices, Inc.
   3 Technology Way
   P.O. Box 9106
   Norwood, MA 02062-9106 USA
   \endcode

 */

/*
** EOF
*/

/*@}*/
